@@ -21,15 +21,27 @@ OC.L10N.register(
     "Invalid directory." : "תיקייה שגויה.",
     "Files" : "קבצים",
     "All files" : "כל הקבצים",
-    "Favorites" : "מועדפים",
+    "File could not be found" : "הקובץ לא ניתן לאיתור",
     "Home" : "בית",
     "Close" : "סגירה",
+    "Favorites" : "מועדפים",
     "Upload cancelled." : "ההעלאה בוטלה.",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "לא ניתן להעלות {filename} כיוון שמדובר בתיקייה או שגודלו 0 בייט",
     "Total file size {size1} exceeds upload limit {size2}" : "גודל הקובת {size1} עובר את מגבלת הגודל להעלאה {size2}",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "לא קיים מספיק מקום פנוי, הקובץ המיועד להעלאה {size1} אבל נשאר {size2} בלבד",
     "Error uploading file \"{fileName}\": {message}" : "שגיאה בזמן העלאת קובץ \"{fileName}\": {message}",
     "Could not get result from server." : "לא ניתן לגשת לתוצאות מהשרת.",
+    "Uploading..." : "העלאה...",
+    "..." : "...",
+    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} hour{plural_s} left",
+    "{hours}:{minutes}h" : "{hours}:{minutes}שעות",
+    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} דקות{plural_s} נשארו",
+    "{minutes}:{seconds}m" : "{minutes}:{seconds}דקות",
+    "{seconds} second{plural_s} left" : "{seconds} שניות{plural_s} נשארו",
+    "{seconds}s" : "{seconds}שניות",
+    "Any moment now..." : "עכשיו בכל רגע...",
+    "Soon..." : "בקרוב...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} מתוך {totalSize} ({bitrate})",
     "File upload is in progress. Leaving the page now will cancel the upload." : "מתבצעת כעת העלאת קבצים. עזיבה של העמוד תבטל את ההעלאה.",
     "Actions" : "פעולות",
     "Download" : "הורדה",
@@ -75,6 +87,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n בייט","%n בייטים"],
     "Favorited" : "מועדף",
     "Favorite" : "מועדף",
+    "Local link" : "קישור מקומי",
     "Folder" : "תיקייה",
     "New folder" : "תיקייה חדשה",
     "{newname} already exists" : "{newname} כבר קיים",
@@ -105,9 +118,9 @@ OC.L10N.register(
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "בשימוש ב- PHP-FPM זה יכול להמשך 5 דקות לשינויים לחול.",
     "Missing permissions to edit from here." : "חסרות הרשאות לעריכה מכאן.",
     "Settings" : "הגדרות",
+    "Show hidden files" : "הצגת קבצים נסתרים",
     "WebDAV" : "WebDAV",
-    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "השתמש בכתובת זו לצורך <a href=\"%s\" target=\"_blank\">כניסה אל הקבצים שלך בעזרת WebDAV</a>",
-    "Cancel upload" : "ביטול ההעלאה",
+    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "ניתן להשתמש בכתובת זו כדי <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">להכנס לקבצים שלך באמצעות WebDAV</a>",
     "No files in here" : "אין כאן קבצים",
     "Upload some content or sync with your devices!" : "יש להעלות קצת תוכן או לסנכרן עם ההתקנים שלך!",
     "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
@@ -117,13 +130,6 @@ OC.L10N.register(
     "No favorites" : "אין מועדפים",
     "Files and folders you mark as favorite will show up here" : "קבצים ותיקיות שסומנו על ידך כמועדפים יוצגו כאן",
     "Text file" : "קובץ טקסט",
-    "New text file.txt" : "קובץ טקסט חדש.txt",
-    "Changed by %2$s" : "שונו על ידי %2$s",
-    "Deleted by %2$s" : "נמחקו על ידי %2$s",
-    "Restored by %2$s" : "שוחזרו על ידי %2$s",
-    "You changed %1$s" : "שינית %1$s",
-    "You created %1$s" : "יצרת %1$s",
-    "You deleted %1$s" : "מחקת %1$s",
-    "You restored %1$s" : "שחזרת %1$s"
+    "New text file.txt" : "קובץ טקסט חדש.txt"
 },
 "nplurals=2; plural=(n != 1);");
