@@ -7,34 +7,18 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "Selhal krok 1. Výjimka: %s",
     "Step 2 failed. Exception: %s" : "Selhal krok 2. Výjimka: %s",
     "External storage" : "Externí úložiště",
-    "Storage with id \"%i\" not found" : "Úložiště s id \"%i\" nebylo nalezeno",
-    "Invalid backend or authentication mechanism class" : "Neplatný backend nebo třída ověřovacího mechanismu",
-    "Invalid mount point" : "Neplatný přípojný bod",
-    "Objectstore forbidden" : "Úložiště objektů zakázáno",
-    "Invalid storage backend \"%s\"" : "Neplatná služba úložiště \"%s\"",
-    "Not permitted to use backend \"%s\"" : "Nebylo povoleno použítí služby \"%s\"",
-    "Not permitted to use authentication mechanism \"%s\"" : "Nebylo povoleno použití ověřovacího mechanismu \"%s\"",
-    "Unsatisfied backend parameters" : "Neuspokojivé parametry služby",
-    "Unsatisfied authentication mechanism parameters" : "Neuspokojivé parametry ověřovacího mechanismu",
-    "Insufficient data: %s" : "Nedostatečná data: %s",
-    "%s" : "%s",
-    "Storage with id \"%i\" is not user editable" : "Úložiště s id \"%i\" uživatelé nemohou upravovat",
+    "Dropbox App Configuration" : "Nastavení aplikace Dropbox",
+    "Google Drive App Configuration" : "Nastavení aplikace Disk Google",
     "Personal" : "Osobní",
     "System" : "Systém",
     "Grant access" : "Povolit přístup",
-    "Access granted" : "Přístup povolen",
     "Error configuring OAuth1" : "Chyba nastavení OAuth1",
     "Error configuring OAuth2" : "Chyba nastavení OAuth2",
     "Generate keys" : "Vytvořit klíče",
     "Error generating key pair" : "Chyba při vytváření páru klíčů",
-    "Enable encryption" : "Povolit šifrování",
-    "Enable previews" : "Povolit náhledy",
-    "Enable sharing" : "Povolit sdílení",
-    "Check for changes" : "Zkontrolovat změny",
-    "Never" : "Nikdy",
-    "Once every direct access" : "Jednou pro každý přímý přístup",
     "All users. Type to select user or group." : "Všichni uživatelé. Začněte psát pro výběr uživatelů a skupin.",
     "(group)" : "(skupina)",
+    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilita s Mac NFD kódováním (pomalé)",
     "Admin defined" : "Nastaveno administrátorem",
     "Saved" : "Uloženo",
     "Empty response from the server" : "Prázdná odpověď serveru",
@@ -53,6 +37,18 @@ OC.L10N.register(
     "Credentials saving failed" : "Uložení přihlašovacích údajů selhalo",
     "Credentials required" : "Vyžadovány přihlašovací údaje",
     "Save" : "Uložit",
+    "Storage with id \"%i\" not found" : "Úložiště s id \"%i\" nebylo nalezeno",
+    "Invalid backend or authentication mechanism class" : "Neplatný backend nebo třída ověřovacího mechanismu",
+    "Invalid mount point" : "Neplatný přípojný bod",
+    "Objectstore forbidden" : "Úložiště objektů zakázáno",
+    "Invalid storage backend \"%s\"" : "Neplatná služba úložiště \"%s\"",
+    "Not permitted to use backend \"%s\"" : "Nebylo povoleno použítí služby \"%s\"",
+    "Not permitted to use authentication mechanism \"%s\"" : "Nebylo povoleno použití ověřovacího mechanismu \"%s\"",
+    "Unsatisfied backend parameters" : "Neuspokojivé parametry služby",
+    "Unsatisfied authentication mechanism parameters" : "Neuspokojivé parametry ověřovacího mechanismu",
+    "Insufficient data: %s" : "Nedostatečná data: %s",
+    "%s" : "%s",
+    "Storage with id \"%i\" is not user editable" : "Úložiště s id \"%i\" uživatelé nemohou upravovat",
     "Access key" : "Přístupový klíč",
     "Secret key" : "Tajný klíč",
     "Builtin" : "Zabudované",
@@ -107,12 +103,18 @@ OC.L10N.register(
     "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> FTP podpora v PHP není povolena nebo nainstalována. Není možné připojení %s. Prosím požádejte svého správce systému ať ji nainstaluje.",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> \"%s\" není instalováno. Není možné připojení %s. Prosím požádejte svého správce systému o instalaci.",
     "No external storage configured" : "Není nakonfigurováno žádné externí úložiště",
-    "You can add external storages in the personal settings" : "Můžete přidat externí úložiště v osobních nastaveních",
+    "You can add external storages in the personal settings" : "Externí úložiště můžete přidat v osobních nastaveních",
     "Name" : "Název",
     "Storage type" : "Typ úložiště",
     "Scope" : "Rozsah",
+    "Enable encryption" : "Povolit šifrování",
+    "Enable previews" : "Povolit náhledy",
+    "Enable sharing" : "Povolit sdílení",
+    "Check for changes" : "Zkontrolovat změny",
+    "Never" : "Nikdy",
+    "Once every direct access" : "Jednou pro každý přímý přístup",
     "External Storage" : "Externí úložiště",
-    "Folder name" : "Název složky",
+    "Folder name" : "Název adresáře",
     "Authentication" : "Ověření",
     "Configuration" : "Nastavení",
     "Available for" : "Dostupné pro",
@@ -120,8 +122,6 @@ OC.L10N.register(
     "Advanced settings" : "Pokročilá nastavení",
     "Delete" : "Smazat",
     "Allow users to mount external storage" : "Povolit uživatelům připojení externího úložiště",
-    "Allow users to mount the following external storage" : "Povolit uživatelů připojit následující externí úložiště",
-    "SMB / CIFS" : "SMB / CIFS",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Některá z nastavených vzdálených úložišť nejsou připojena. Pro více informací prosím klikněte na červenou šipku(y)"
+    "Allow users to mount the following external storage" : "Povolit uživatelů připojit následující externí úložiště"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
