@@ -7,34 +7,18 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "El paso 1 falló. Excepción: %s",
     "Step 2 failed. Exception: %s" : "El paso 2 falló. Excepción: %s",
     "External storage" : "Almacenamiento externo",
-    "Storage with id \"%i\" not found" : "No se ha encontrado almacenamiento con id \"%i\"",
-    "Invalid backend or authentication mechanism class" : "Sistema o mecanismo de autentificación inválido",
-    "Invalid mount point" : "Punto de montaje no válido",
-    "Objectstore forbidden" : "Objeto de almacenaje prohibido",
-    "Invalid storage backend \"%s\"" : "Motor de almacenamiento no válido «%s»",
-    "Not permitted to use backend \"%s\"" : "No se permite usar el mecanismo \"%s\"",
-    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido usar el mecanismo de autentificación \"%s\"",
-    "Unsatisfied backend parameters" : "Los parámetros del sistema no son válidos",
-    "Unsatisfied authentication mechanism parameters" : "Los parámetros del mecanismo de autentificación no son válidos",
-    "Insufficient data: %s" : "Datos insuficientes: %s",
-    "%s" : "%s",
-    "Storage with id \"%i\" is not user editable" : "El almacenamiento con id \"%i\" no es editable por usuarios",
+    "Dropbox App Configuration" : "Configuración de la app de Dropbox",
+    "Google Drive App Configuration" : "Configuración de la app de Google Drive",
     "Personal" : "Personal",
     "System" : "Sistema",
     "Grant access" : "Conceder acceso",
-    "Access granted" : "Acceso concedido",
     "Error configuring OAuth1" : "Error al configurar OAuth1",
     "Error configuring OAuth2" : "Error al configurar OAuth2",
     "Generate keys" : "Generar claves",
     "Error generating key pair" : "Error al generar el par de claves",
-    "Enable encryption" : "Habilitar cifrado",
-    "Enable previews" : "Habilitar previsualizaciones",
-    "Enable sharing" : "Habilitar comparto",
-    "Check for changes" : "Comprobar si hay cambios",
-    "Never" : "Nunca",
-    "Once every direct access" : "Una vez cada acceso directo",
     "All users. Type to select user or group." : "Todos los usuarios. Teclee para seleccionar un usuario o grupo.",
     "(group)" : "(grupo)",
+    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidad con codificación Mac MFD (lento)",
     "Admin defined" : "Admin definido",
     "Saved" : "Guardado",
     "Empty response from the server" : "Respuesta vacía desde el servidor",
@@ -53,6 +37,18 @@ OC.L10N.register(
     "Credentials saving failed" : "Guardado de credenciales fallido",
     "Credentials required" : "Credenciales requeridos",
     "Save" : "Guardar",
+    "Storage with id \"%i\" not found" : "No se ha encontrado almacenamiento con id \"%i\"",
+    "Invalid backend or authentication mechanism class" : "Sistema o mecanismo de autentificación inválido",
+    "Invalid mount point" : "Punto de montaje no válido",
+    "Objectstore forbidden" : "Objeto de almacenaje prohibido",
+    "Invalid storage backend \"%s\"" : "Motor de almacenamiento no válido «%s»",
+    "Not permitted to use backend \"%s\"" : "No se permite usar el mecanismo \"%s\"",
+    "Not permitted to use authentication mechanism \"%s\"" : "No está permitido usar el mecanismo de autentificación \"%s\"",
+    "Unsatisfied backend parameters" : "Los parámetros del sistema no son válidos",
+    "Unsatisfied authentication mechanism parameters" : "Los parámetros del mecanismo de autentificación no son válidos",
+    "Insufficient data: %s" : "Datos insuficientes: %s",
+    "%s" : "%s",
+    "Storage with id \"%i\" is not user editable" : "El almacenamiento con id \"%i\" no es editable por usuarios",
     "Access key" : "Clave de acceso",
     "Secret key" : "Clave secreta",
     "Builtin" : "Incorporado",
@@ -69,7 +65,7 @@ OC.L10N.register(
     "Rackspace" : "Espacio de Rack",
     "API key" : "Clave API",
     "Username and password" : "Nombre de usuario y contraseña",
-    "Log-in credentials, save in session" : "Iniciar credenciales, guardar en la sesión",
+    "Log-in credentials, save in session" : "Credenciales de login, guardar en la sesión",
     "RSA public key" : "Clave pública RSA",
     "Public key" : "Clave pública",
     "Amazon S3" : "Amazon S3",
@@ -111,6 +107,12 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Storage type" : "Tipo de almacenamiento",
     "Scope" : "Ámbito",
+    "Enable encryption" : "Habilitar cifrado",
+    "Enable previews" : "Habilitar previsualizaciones",
+    "Enable sharing" : "Habilitar el uso compartido",
+    "Check for changes" : "Comprobar si hay cambios",
+    "Never" : "Nunca",
+    "Once every direct access" : "Una vez cada acceso directo",
     "External Storage" : "Almacenamiento externo",
     "Folder name" : "Nombre de la carpeta",
     "Authentication" : "Autentificación",
@@ -120,8 +122,6 @@ OC.L10N.register(
     "Advanced settings" : "Configuración avanzada",
     "Delete" : "Eliminar",
     "Allow users to mount external storage" : "Permitir a los usuarios montar un almacenamiento externo",
-    "Allow users to mount the following external storage" : "Permitir a los usuarios montar el siguiente almacenamiento externo",
-    "SMB / CIFS" : "SMB / CIFS",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Algunos de los puntos de montaje externos configurados no están conectados. Por favor, haga clic en la fila roja (s) para obtener más información"
+    "Allow users to mount the following external storage" : "Permitir a los usuarios montar el siguiente almacenamiento externo"
 },
 "nplurals=2; plural=(n != 1);");
