@@ -7,6 +7,35 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "Adım 1 başarısız. Özel durum: %s",
     "Step 2 failed. Exception: %s" : "Adım 2 başarısız. Özel durum: %s",
     "External storage" : "Harici depolama",
+    "Dropbox App Configuration" : "Dropbox'u yapılandır",
+    "Google Drive App Configuration" : "Google Drive'ı yapılandır",
+    "Personal" : "Kişisel",
+    "System" : "Sistem",
+    "Grant access" : "Erişimi sağla",
+    "Error configuring OAuth1" : "OAuth1 yapılandırma hatası",
+    "Error configuring OAuth2" : "OAuth2 yapılandırma hatası",
+    "Generate keys" : "Anahtarlar üret",
+    "Error generating key pair" : "Anahtar çifti üretirken hata",
+    "All users. Type to select user or group." : "Tüm kullanıcılar. Kullanıcı veya grup seçmek için yazın.",
+    "(group)" : "(grup)",
+    "Admin defined" : "Yönetici tanımlandı",
+    "Saved" : "Kaydedildi",
+    "Empty response from the server" : "Sunucudan boş yanıt",
+    "Couldn't access. Please logout and login to activate this mount point" : "Erişilemedi. Lütfen bu bağlama noktasını etkinleştirmek için tekrar oturumu kapatıp açın.",
+    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud sunucusundan bilgi alınamadı: {code} {type}",
+    "Couldn't get the list of external mount points: {type}" : "Harici bağlama noktalarının listesi alınamadı: {type}",
+    "There was an error with message: " : "Şu mesajla bir hata oluştu:",
+    "External mount error" : "Harici bağlama hatası",
+    "external-storage" : "harici-depolama",
+    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows ağ sürücüsü bağlama nokta listesi alınamadı: sunucudan boş yanıt",
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Yapılandırılmış harici bağlama noktalarından bazıları bağlı değil. Lütfen daha fazla bilgi için kırmızı satırlara tıklayın",
+    "Please enter the credentials for the {mount} mount" : "{mount} bağlaması için kimlik bilgilerini girin",
+    "Username" : "Kullanıcı Adı",
+    "Password" : "Parola",
+    "Credentials saved" : "Kimlik bilgileri kaydedildi",
+    "Credentials saving failed" : "Kimlik bilgileri kaydedilemedi",
+    "Credentials required" : "Kimlik bilgileri gerekli",
+    "Save" : "Kaydet",
     "Storage with id \"%i\" not found" : "\"%i\" kimliği ile bir depolama bulunamadı",
     "Invalid backend or authentication mechanism class" : "Geçersiz arka uç veya kimlik doğrulama mekanizma sınıfı",
     "Invalid mount point" : "Geçersiz bağlama noktası",
@@ -19,33 +48,6 @@ OC.L10N.register(
     "Insufficient data: %s" : "Yetersiz veri: %s",
     "%s" : "%s",
     "Storage with id \"%i\" is not user editable" : "\"%i\" kimliği ile bir depolama bulunamadı",
-    "Personal" : "Kişisel",
-    "System" : "Sistem",
-    "Grant access" : "Erişimi sağla",
-    "Access granted" : "Giriş kabul edildi",
-    "Error configuring OAuth1" : "OAuth1 yapılandırma hatası",
-    "Error configuring OAuth2" : "OAuth2 yapılandırma hatası",
-    "Generate keys" : "Anahtarlar üret",
-    "Error generating key pair" : "Anahtar çifti üretirken hata",
-    "Enable encryption" : "Şifrelemeyi aç",
-    "Enable previews" : "Önizlemeleri aç",
-    "Enable sharing" : "Paylaşımı etkinleştir",
-    "Check for changes" : "Değişiklikleri denetle",
-    "Never" : "Daha yeni",
-    "Once every direct access" : "Her doğrudan erişimde bir kez",
-    "All users. Type to select user or group." : "Tüm kullanıcılar. Kullanıcı veya grup seçmek için yazın.",
-    "(group)" : "(grup)",
-    "Admin defined" : "Yönetici tanımlandı",
-    "Saved" : "Kaydedildi",
-    "Empty response from the server" : "Sunucudan boş yanıt",
-    "Couldn't access. Please logout and login to activate this mount point" : "Erişilemedi. Lütfen bu bağlama noktasını etkinleştirmek için tekrar oturumu kapatıp açın.",
-    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud sunucusundan bilgi alınamadı: {code} {type}",
-    "Couldn't get the list of external mount points: {type}" : "Harici bağlama noktalarının listesi alınamadı: {type}",
-    "There was an error with message: " : "Şu mesajla bir hata oluştu:",
-    "External mount error" : "Harici bağlama hatası",
-    "Username" : "Kullanıcı Adı",
-    "Password" : "Parola",
-    "Save" : "Kaydet",
     "Access key" : "Erişim anahtarı",
     "Secret key" : "Gizli anahtar",
     "Builtin" : "Yerleşik",
@@ -62,6 +64,7 @@ OC.L10N.register(
     "Rackspace" : "Rackspace",
     "API key" : "API anahtarı",
     "Username and password" : "Kullanıcı adı ve parola",
+    "Log-in credentials, save in session" : "Oturum kimlik bilgileri, oturumda kaydet",
     "RSA public key" : "RSA ortak anahtarı",
     "Public key" : "Ortak anahtar",
     "Amazon S3" : "Amazon S3",
@@ -103,6 +106,12 @@ OC.L10N.register(
     "Name" : "Ad",
     "Storage type" : "Depolama türü",
     "Scope" : "Kapsam",
+    "Enable encryption" : "Şifrelemeyi aç",
+    "Enable previews" : "Önizlemeleri aç",
+    "Enable sharing" : "Paylaşımı etkinleştir",
+    "Check for changes" : "Değişiklikleri denetle",
+    "Never" : "Daha yeni",
+    "Once every direct access" : "Her doğrudan erişimde bir kez",
     "External Storage" : "Harici Depolama",
     "Folder name" : "Klasör ismi",
     "Authentication" : "Kimlik Doğrulama",
