@@ -20,10 +20,16 @@
  */
 
 
+use OCA\Files_Trashbin\AppInfo\Application;
 use OCA\Files_Trashbin\Command\CleanUp;
+use OCA\Files_Trashbin\Command\ExpireTrash;
 
+$app = new Application();
+$expiration = $app->getContainer()->query('Expiration');
 $userManager = OC::$server->getUserManager();
 $rootFolder = \OC::$server->getRootFolder();
 $dbConnection = \OC::$server->getDatabaseConnection();
+
 /** @var Symfony\Component\Console\Application $application */
 $application->add(new CleanUp($rootFolder, $userManager, $dbConnection));
+$application->add(new ExpireTrash($userManager, $expiration));
