@@ -1,6 +1,6 @@
 <?php
 /**
- * @author Björn Schießle <schiessle@owncloud.com>
+ * @author Björn Schießle <bjoern@schiessle.org>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
  * @copyright Copyright (c) 2016, ownCloud, Inc.
@@ -39,6 +39,3 @@ if (version_compare($installedVersion, '0.6.4', '<')) {
 	$config->setSystemValue('trashbin_retention_obligation', $newObligation);
 	$config->deleteSystemValue('trashbin_auto_expire');
 }
-
-// Cron job for deleting expired trash items
-\OC::$server->getJobList()->add('OCA\Files_Trashbin\BackgroundJob\ExpireTrash');
