@@ -5,11 +5,11 @@ OC.L10N.register(
     "Couldn't restore %s" : "No se puede restaurar %s",
     "Deleted files" : "Archivos eliminados",
     "Restore" : "Recuperar",
+    "Delete" : "Eliminar",
     "Delete permanently" : "Eliminar permanentemente",
     "Error" : "Error",
     "restored" : "recuperado",
     "Name" : "Nombre",
-    "Deleted" : "Eliminado",
-    "Delete" : "Eliminar"
+    "Deleted" : "Eliminado"
 },
 "nplurals=2; plural=(n != 1);");
