@@ -20,9 +20,14 @@
  */
 
 
+use OCA\Files_Versions\AppInfo\Application;
 use OCA\Files_Versions\Command\CleanUp;
+use OCA\Files_Versions\Command\ExpireVersions;
 
+$app = new Application();
+$expiration = $app->getContainer()->query('Expiration');
 $userManager = OC::$server->getUserManager();
 $rootFolder = \OC::$server->getRootFolder();
 /** @var Symfony\Component\Console\Application $application */
 $application->add(new CleanUp($rootFolder, $userManager));
+$application->add(new ExpireVersions($userManager, $expiration));
