@@ -1,21 +1,28 @@
 OC.L10N.register(
     "systemtags",
     {
-    "<strong>System tags</strong> for a file have been modified" : "I <strong>tag di sistema</strong> per un file sono stati modificati",
-    "%1$s assigned system tag %3$s" : "%1$s ha assegnato il tag di sistema %3$s",
-    "%1$s unassigned system tag %3$s" : "%1$s ha rimosso il tag di sistema %3$s",
-    "%1$s created system tag %2$s" : "%1$s ha creato il tag di sistema %2$s",
-    "%1$s deleted system tag %2$s" : "%1$s ha eliminato il tag di sistema %2$s",
-    "%1$s updated system tag %3$s to %2$s" : "%1$s ha aggiornato il tag di sistema %3$s in %2$s",
-    "%1$s assigned system tag %3$s to %2$s" : "%1$s ha assegnato il tag di sistema %3$s a %2$s",
-    "%1$s unassigned system tag %3$s from %2$s" : "%1$s ha rimosso il tag di sistema %3$s da %2$s",
-    "%s (not-assignable)" : "%s (non assegnabile)",
-    "%s (invisible)" : "%s (invisibile)",
     "Tags" : "Tag",
     "Tagged files" : "File con tag",
     "Select tags to filter by" : "Seleziona i tag per filtrare",
     "Please select tags to filter by" : "Seleziona i tag per filtrare",
     "No files found for the selected tags" : "Nessun file trovato per i tag selezionati",
+    "<strong>System tags</strong> for a file have been modified" : "I <strong>tag di sistema</strong> per un file sono stati modificati",
+    "You assigned system tag %3$s" : "Hai assegnato il tag di sistema %3$s",
+    "%1$s assigned system tag %3$s" : "%1$s ha assegnato il tag di sistema %3$s",
+    "You unassigned system tag %3$s" : "Hai rimosso il tag di sistema %3$s",
+    "%1$s unassigned system tag %3$s" : "%1$s ha rimosso il tag di sistema %3$s",
+    "You created system tag %2$s" : "Hai creato il tag di sistema %2$s",
+    "%1$s created system tag %2$s" : "%1$s ha creato il tag di sistema %2$s",
+    "You deleted system tag %2$s" : "Hai eliminato il tag di sistema %2$s",
+    "%1$s deleted system tag %2$s" : "%1$s ha eliminato il tag di sistema %2$s",
+    "You updated system tag %3$s to %2$s" : "Hai aggiornato il tag di sistema %3$s in %2$s",
+    "%1$s updated system tag %3$s to %2$s" : "%1$s ha aggiornato il tag di sistema %3$s in %2$s",
+    "You assigned system tag %3$s to %2$s" : "Hai assegnato il tag di sistema %3$s a %2$s",
+    "%1$s assigned system tag %3$s to %2$s" : "%1$s ha assegnato il tag di sistema %3$s a %2$s",
+    "You unassigned system tag %3$s from %2$s" : "Hai rimosso il tag di sistema %3$s da %2$s",
+    "%1$s unassigned system tag %3$s from %2$s" : "%1$s ha rimosso il tag di sistema %3$s da %2$s",
+    "%s (restricted)" : "%s (limitato)",
+    "%s (invisible)" : "%s (invisibile)",
     "No files in here" : "Qui non c'è alcun file",
     "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
     "Name" : "Nome",
