@@ -39,8 +39,16 @@ $(document).ready(function(){
 			});
 		});
 	});
+
 	$('#release-channel').change(function() {
 		var newChannel = $('#release-channel').find(":selected").val();
+
+		if (newChannel === 'git' || newChannel === 'daily') {
+			$('#oca_updatenotification_groups em').removeClass('hidden');
+		} else {
+			$('#oca_updatenotification_groups em').addClass('hidden');
+		}
+
 		$.post(
 			OC.generateUrl('/apps/updatenotification/channel'),
 			{
@@ -51,4 +59,12 @@ $(document).ready(function(){
 			}
 		);
 	});
+
+	var $notificationTargetGroups = $('#oca_updatenotification_groups_list');
+	OC.Settings.setupGroupsSelect($notificationTargetGroups);
+	$notificationTargetGroups.change(function(ev) {
+		var groups = ev.val || [];
+		groups = JSON.stringify(groups);
+		OC.AppConfig.setValue('updatenotification', 'notify_groups', groups);
+	});
 });
