@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Nebylo možné odeslat email následujícím uživatelům: %s",
-    "Preparing update" : "Příprava na aktualizaci",
-    "Turned on maintenance mode" : "Zapnut režim údržby",
-    "Turned off maintenance mode" : "Vypnut režim údržby",
-    "Maintenance mode is kept active" : "Mód údržby je aktivní",
-    "Updating database schema" : "Aktualizace schéma databáze",
-    "Updated database" : "Zaktualizována databáze",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Probíhá ověření, zda je možné aktualizovat schéma databáze (toto může trvat déle v závislosti na velikosti databáze)",
-    "Checked database schema update" : "Aktualizace schéma databáze byla ověřena",
-    "Checking updates of apps" : "Kontrola aktualizace aplikací",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Probíhá ověření, zda je možné aktualizovat schéma databáze %s (toto může trvat déle v závislosti na velikosti databáze)",
-    "Checked database schema update for apps" : "Aktualizace schéma databáze aplikací byla ověřena",
-    "Updated \"%s\" to %s" : "Aktualizováno z \"%s\" na %s",
-    "Repair warning: " : "Upozornění opravy:",
-    "Repair error: " : "Chyba opravy:",
-    "Set log level to debug" : "Nastavit úroveň logování na debug",
-    "Reset log level" : "Resetovat úroveň logování",
-    "Starting code integrity check" : "Spouští se kontrola integrity kódu",
-    "Finished code integrity check" : "Kontrola integrity kódu dokončena",
-    "%s (3rdparty)" : "%s (3. strana)",
-    "%s (incompatible)" : "%s (nekompatibilní)",
-    "Following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
-    "Already up to date" : "Je již aktuální",
     "Please select a file." : "Prosím vyberte soubor.",
     "File is too big" : "Soubor je příliš velký",
     "Invalid file provided" : "Zadán neplatný soubor",
@@ -41,6 +18,39 @@ OC.L10N.register(
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Nelze odeslat email pro změnu hesla, protože u tohoto uživatelského jména není uvedena emailová adresa. Kontaktujte prosím svého administrátora.",
     "%s password reset" : "reset hesla %s",
     "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat email pro změnu hesla. Kontaktujte svého správce systému.",
+    "Error loading tags" : "Chyba při načítání štítků",
+    "Tag already exists" : "Štítek již existuje",
+    "Error deleting tag(s)" : "Chyba při mazání štítku(ů)",
+    "Error tagging" : "Chyba při označování štítkem",
+    "Error untagging" : "Chyba při odznačování štítků",
+    "Error favoriting" : "Chyba při označování jako oblíbené",
+    "Error unfavoriting" : "Chyba při odznačování jako oblíbené",
+    "Couldn't send mail to following users: %s " : "Nebylo možné odeslat email následujícím uživatelům: %s",
+    "Preparing update" : "Příprava na aktualizaci",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Upozornění opravy:",
+    "Repair error: " : "Chyba opravy:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Prosím použijte aktualizační příkazový řádek, protože automatická aktualizace je zakázána v config.php",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrola tabulky %s",
+    "Turned on maintenance mode" : "Zapnut režim údržby",
+    "Turned off maintenance mode" : "Vypnut režim údržby",
+    "Maintenance mode is kept active" : "Mód údržby je aktivní",
+    "Updating database schema" : "Aktualizace schéma databáze",
+    "Updated database" : "Zaktualizována databáze",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Probíhá ověření, zda je možné aktualizovat schéma databáze (toto může trvat déle v závislosti na velikosti databáze)",
+    "Checked database schema update" : "Aktualizace schéma databáze byla ověřena",
+    "Checking updates of apps" : "Kontrola aktualizace aplikací",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Probíhá ověření, zda je možné aktualizovat schéma databáze %s (toto může trvat déle v závislosti na velikosti databáze)",
+    "Checked database schema update for apps" : "Aktualizace schéma databáze aplikací byla ověřena",
+    "Updated \"%s\" to %s" : "Aktualizováno z \"%s\" na %s",
+    "Set log level to debug" : "Nastavit úroveň logování na debug",
+    "Reset log level" : "Resetovat úroveň logování",
+    "Starting code integrity check" : "Spouští se kontrola integrity kódu",
+    "Finished code integrity check" : "Kontrola integrity kódu dokončena",
+    "%s (3rdparty)" : "%s (3. strana)",
+    "%s (incompatible)" : "%s (nekompatibilní)",
+    "Following apps have been disabled: %s" : "Následující aplikace byly vypnuty: %s",
+    "Already up to date" : "Je již aktuální",
     "Sunday" : "Neděle",
     "Monday" : "Pondělí",
     "Tuesday" : "Úterý",
@@ -88,10 +98,11 @@ OC.L10N.register(
     "Dec." : "prosinec",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Došlo k problémům při kontrole integrity kódu. Více informací…</a>",
     "Settings" : "Nastavení",
+    "Problem loading page, reloading in 5 seconds" : "Problém s načítáním stránky, stránka se obnoví za 5 sekund",
     "Saving..." : "Ukládám...",
     "Dismiss" : "Zamítnout",
     "seconds ago" : "před pár sekundami",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovení hesla byl odeslán na vaši emailovou adresu. Pokud jej v krátké době neobdržíte, zkontrolujte složku nevyžádané pošty a koš.<br>Pokud jej nenaleznete, kontaktujte svého správce systému.",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Odkaz na obnovení hesla byl odeslán na vaši emailovou adresu. Pokud jej v krátké době neobdržíte, zkontrolujte nevyžádanou poštu a koš.<br>Pokud jej nenaleznete, kontaktujte svého správce systému.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše soubory jsou šifrovány. Pokud jste nepovolili klíč pro obnovení, neexistuje způsob jak získat po změně hesla vaše data zpět.<br />Pokud si nejste jisti co dělat, kontaktujte nejprve svého správce systému, než budete pokračovat. <br />Opravdu si přejete pokračovat?",
     "I know what I'm doing" : "Vím co dělám",
     "Password can not be changed. Please contact your administrator." : "Heslo nelze změnit. Kontaktujte prosím svého správce systému.",
@@ -119,18 +130,18 @@ OC.L10N.register(
     "Good password" : "Dobré heslo",
     "Strong password" : "Silné heslo",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Váš webový server ještě není správně nastaven pro umožnění synchronizace souborů, protože rozhraní WebDAV je pravděpodobně rozbité.",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Tento webový server není správně nastaven pro rozpoznání \"{url}\". Více informací lze nalézt v naší <a target=\"_blank\" href=\"{docLink}\">dokumentaci</a>.",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Tento webový server není správně nastaven pro rozpoznání \"{url}\". Více informací lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaci</a>.",
     "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Tento server nemá funkční připojení k Internetu. Některé moduly jako např. externí úložiště, oznámení o dostupných aktualizacích nebo instalace aplikací třetích stran nebudou fungovat. Přístup k souborům z jiných míst a odesílání oznamovacích emailů také nemusí fungovat. Pokud chcete využívat všechny možnosti ownCloud, doporučujeme povolit pro tento server připojení k Internetu.",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Nebyla nakonfigurována paměťová cache. Pro zlepšení výkonu a dostupnosti ji prosím nakonfigurujte. Další informace lze nalézt v naší <a href=\"{docLink}\">dokumentaci</a>.",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "PHP nemá práva pro čtení v /dev/urandom, to je ale z bezpečnostních důvodů velmi doporučováno. Více informací lze nalézt v <a href=\"{docLink}\">dokumentaci</a>.",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Vaše verze PHP ({version}) již není <a href=\"{phpLink}\">podporována</a>. Doporučujeme aktualizovat na poslední verzi PHP pro využití vylepšení výkonu a bezpečnosti.",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Konfigurace hlaviček zpětné proxy není správná nebo přistupujete na ownCloud přes důvěryhodnou proxy. Pokud přistupujete na ownCloud přes nedůvěryhodnou proxy je toto považováno za bezpečnostní problém který může útočníkovi umožnit záměnu IP adresy viděné ownCloudem. Více informací lze nalézt v naší <a href=\"{docLink}\">dokumentaci</a>.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached je nakonfigurován jako distribuovaná cache, ale je nainstalován nesprávný PHP modul \"memcache\". \\OC\\Memcache\\Memcached podporuje pouze \"memcached\" a ne \"memcache\". Projděte si <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki popisující oba moduly</a>.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Některé soubory neprošly kontrolou integrity. Více informací o tom jak tento problém vyřešit, lze nalézt v naší <a href=\"{docLink}\">dokumentaci</a>. (<a target=\"_blank\" href=\"{codeIntegrityDownloadEndpoint}\">Seznam neplatných souborů…</a> / <a href=\"{rescanEndpoint}\">Znovu ověřit…</a>)",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Nebyla nakonfigurována paměťová cache. Pokud je dostupná, nakonfigurujte ji prosím pro zlepšení výkonu. Další informace lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaci</a>.",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP nemá práva pro čtení v /dev/urandom, to je ale z bezpečnostních důvodů velmi doporučováno. Více informací lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaci</a>.",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Aktuálně používáte PHP {version}. Doporučujeme aktualizovat verzi PHP, abyste mohli využít <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">výkonnostních a bezpečnostních aktualizací poskytovaných autory PHP</a> tak rychle, jak to vaše distribuce umožňuje.",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurace hlaviček reverzní proxy není správná nebo přistupujete na ownCloud z důvěryhodné proxy. Pokud nepřistupujete k ownCloud z důvěryhodné proxy, potom je toto bezpečností chyba a může útočníkovi umožnit falšovat IP adresu, kterou ownCloud vidí. Další informace lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaci</a>.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Je nakonfigurován memcached jako distribuovaná cache, ale je nainstalovaný nesprávný PHP modul \"memcache\". \\OC\\Memcache\\Memcached podporuje pouze \"memcached\" a ne \"memcache\". Podívejte se na <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki o obou modulech</a>.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Některé soubory neprošly kontrolou integrity. Více informací o tom jak tento problém vyřešit, lze nalézt v naší <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentaci</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Seznam neplatných souborů…</a> / <a href=\"{rescanEndpoint}\">Znovu ověřit…</a>)",
     "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Váš datový adresář i vaše soubory jsou pravděpodobně přístupné z Internetu. Soubor .htaccess nefunguje. Důrazně doporučujeme nakonfigurovat webový server tak, aby datový adresář nebyl nadále přístupný, nebo přesunout datový adresář mimo prostor zpřístupňovaný webovým serverem.",
     "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP hlavička \"{header}\" není nakonfigurována ve shodě s \"{expected}\". To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
-    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "HTTP hlavička \"Strict-Transport-Security\" není nakonfigurována na minimum \"{seconds}\" sekund. Pro vylepšení bezpečnosti doporučujeme povolit HSTS dle popisu v našich <a href=\"{docUrl}\">bezpečnostních tipech</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP hlavička \"Strict-Transport-Security\" není nakonfigurována na minimum \"{seconds}\" sekund. Pro vylepšení bezpečnosti doporučujeme povolit HSTS dle popisu v našich <a href=\"{docUrl}\" rel=\"noreferrer\">bezpečnostních tipech</a>.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Přistupujete na tuto stránku přes protokol HTTP. Důrazně doporučujeme nakonfigurovat server tak, aby vyžadoval použití HTTPS jak je popsáno v našich <a href=\"{docUrl}\">bezpečnostních tipech</a>.",
     "Shared" : "Sdílené",
     "Shared with {recipients}" : "Sdíleno s {recipients}",
@@ -143,8 +154,6 @@ OC.L10N.register(
     "Expiration" : "Konec platnosti",
     "Expiration date" : "Datum vypršení platnosti",
     "Choose a password for the public link" : "Zadej heslo pro tento veřejný odkaz",
-    "Sending ..." : "Odesílám ...",
-    "Email sent" : "Email odeslán",
     "Resharing is not allowed" : "Sdílení již sdílené položky není povoleno",
     "Share link" : "Sdílet odkaz",
     "Link" : "Odkaz",
@@ -153,6 +162,9 @@ OC.L10N.register(
     "Allow editing" : "Povolit úpravy",
     "Email link to person" : "Odeslat osobě odkaz emailem",
     "Send" : "Odeslat",
+    "Sending ..." : "Odesílám ...",
+    "Email sent" : "Email odeslán",
+    "Send link via email" : "Odeslat odkaz přes email",
     "Shared with you and the group {group} by {owner}" : "S Vámi a skupinou {group} sdílí {owner}",
     "Shared with you by {owner}" : "S Vámi sdílí {owner}",
     "group" : "skupina",
@@ -168,16 +180,22 @@ OC.L10N.register(
     "Could not unshare" : "Nelze zrušit sdílení",
     "Share details could not be loaded for this item." : "Detaily sdílení pro tuto položku nelze načíst.",
     "No users or groups found for {search}" : "Nebyli nalezeni žádní členové ani skupiny pro {search}",
-    "An error occured. Please try again" : "Nastala chyba. Prosím zkuste to znovu",
+    "No users found for {search}" : "Nebyli nalezeni žádní uživatelé pro {search}",
+    "An error occurred. Please try again" : "Došlo k chybě. Zkuste to prosím znovu",
+    "{sharee} (group)" : "{sharee} (skupina)",
+    "{sharee} (at {server})" : "{sharee} (na {server})",
+    "{sharee} (remote)" : "{sharee} (vzdálený)",
     "Share" : "Sdílet",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Sdílejte s lidmi na ownClouds použitím syntaxe username@example.com/owncloud",
-    "Share with users or groups …" : "Sdílet s uživateli nebo skupinami",
-    "Share with users, groups or remote users …" : "Sdílet s uživateli, skupinami nebo vzdálenými uživateli",
+    "Share with users…" : "Sdílet s uživateli...",
+    "Share with users, groups or remote users…" : "Sdílet s uživateli, skupinami nebo vzdálenými uživateli...",
+    "Share with users or groups…" : "Sdílet s uživateli nebo skupinami...",
+    "Share with users or remote users…" : "Sdílet s uživateli nebo vzdálenými uživateli...",
     "Error removing share" : "Chyba při odstraňování sdílení",
     "Warning" : "Varování",
     "Error while sending notification" : "Chyba při odesílání upozornění",
     "Non-existing tag #{tag}" : "Neexistující tag #{tag}",
-    "not assignable" : "nepřiřaditelný",
+    "restricted" : "omezeno",
     "invisible" : "neviditelný",
     "({scope})" : "({scope})",
     "Delete" : "Smazat",
@@ -194,13 +212,14 @@ OC.L10N.register(
     "sunny" : "slunečno",
     "Hello {name}, the weather is {weather}" : "Ahoj {name}, je {weather}",
     "Hello {name}" : "Vítej, {name}",
+    "new" : "nový",
     "_download %n file_::_download %n files_" : ["stáhnout %n soubor","stáhnout %n soubory","stáhnout %n souborů"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Probíhá aktualizace, opuštění této stránky může v některých prostředích přerušit proces.",
-    "Updating {productName} to version {version}, this may take a while." : "Aktualizuji {productName} na verzi {version}, může to chvíli trvat.",
+    "Updating to {version}" : "Aktualizace na {version}",
     "An error occurred." : "Došlo k chybě.",
     "Please reload the page." : "Načtěte stránku znovu, prosím.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizace nebyla úspěšná. Pro více informací si <a href=\"{url}\">přečtěte komentáře ve fóru</a> pojednávající o tomto problému.",
-    "The update was unsuccessful. " : "Aktualizace nebyla úspěšná.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Aktualizace neproběhla úspěšně. Nahlaste prosím problém <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">komunitě ownCloud</a>",
     "The update was successful. There were warnings." : "Aktualizace byla úspěšná. Zachycen výskyt varování.",
     "The update was successful. Redirecting you to ownCloud now." : "Aktualizace byla úspěšná. Přesměrovávám na ownCloud.",
     "Searching other places" : "Prohledávání ostatních umístění",
@@ -211,13 +230,6 @@ OC.L10N.register(
     "Apps" : "Aplikace",
     "Admin" : "Administrace",
     "Help" : "Nápověda",
-    "Error loading tags" : "Chyba při načítání štítků",
-    "Tag already exists" : "Štítek již existuje",
-    "Error deleting tag(s)" : "Chyba při mazání štítku(ů)",
-    "Error tagging" : "Chyba při označování štítkem",
-    "Error untagging" : "Chyba při odznačování štítků",
-    "Error favoriting" : "Chyba při označování jako oblíbené",
-    "Error unfavoriting" : "Chyba při odznačování jako oblíbené",
     "Access forbidden" : "Přístup zakázán",
     "File not found" : "Soubor nenalezen",
     "The specified document has not been found on the server." : "Požadovaný dokument nebyl na serveru nalezen.",
@@ -240,11 +252,11 @@ OC.L10N.register(
     "Trace" : "Trasa",
     "Security warning" : "Bezpečnostní varování",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář s daty a soubory jsou dostupné z internetu, protože soubor .htaccess nefunguje.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Pro informace, jak správně nastavit váš server, se podívejte do <a href=\"%s\" target=\"_blank\">dokumentace</a>.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Pro informace, jak správně nastavit váš server, se podívejte do <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dokumentace</a>.",
     "Create an <strong>admin account</strong>" : "Vytvořit <strong>účet správce</strong>",
     "Username" : "Uživatelské jméno",
     "Storage & database" : "Úložiště & databáze",
-    "Data folder" : "Složka s daty",
+    "Data folder" : "Adresář s daty",
     "Configure the database" : "Nastavit databázi",
     "Only %s is available." : "Pouze %s je dostupný.",
     "Install and activate additional PHP modules to choose other database types." : "Pro výběr jiných typů databáze je třeba nainstalovat a povolit dodatečné PHP moduly.",
@@ -268,8 +280,9 @@ OC.L10N.register(
     "Search" : "Hledat",
     "Server side authentication failed!" : "Autentizace na serveru selhala!",
     "Please contact your administrator." : "Kontaktujte prosím svého správce systému.",
-    "An internal error occured." : "Nastala vnitřní chyba.",
+    "An internal error occurred." : "Nastala vnitřní chyba.",
     "Please try again or contact your administrator." : "Prosím zkuste to znovu nebo kontaktujte vašeho správce.",
+    "Username or email" : "Uživatelské jméno nebo email",
     "Log in" : "Přihlásit",
     "Wrong password. Reset it?" : "Nesprávné heslo. Resetovat?",
     "Wrong password." : "Chybné heslo.",
@@ -283,6 +296,11 @@ OC.L10N.register(
     "This means only administrators can use the instance." : "To znamená, že pouze správci systému mohou aplikaci používat.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správce systému, pokud se tato zpráva objevuje opakovaně nebo nečekaně.",
     "Thank you for your patience." : "Děkujeme za vaši trpělivost.",
+    "Two-step verification" : "Dvoufázové ověření",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Bylo zapnuto vylepšené zabezpečení pro tento účet. Přihlašte se za použití druhého faktoru.",
+    "Cancel login" : "Zrušit přihlášení",
+    "Please authenticate using the selected factor." : "Přihlašte se za použití vybraného faktoru.",
+    "An error occured while verifying the token" : "Chyba při ověřování tokenu",
     "You are accessing the server from an untrusted domain." : "Přistupujete na server z nedůvěryhodné domény.",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Kontaktujte prosím svého správce. Pokud spravujete tuto instalaci, nastavte \"trusted_domains\" v souboru config/config.php. Příklad konfigurace najdete v souboru config/config.sample.php.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "V závislosti na vaší konfiguraci vám může být, jako správci, umožněno použití tlačítka níže k označení této domény jako důvěryhodné.",
@@ -295,9 +313,11 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Před provedením dalšího kroku se prosím ujistěte, že databáze a konfigurační a datový adresář byly zazálohovány.  ",
     "Start update" : "Spustit aktualizaci",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Abyste zabránili vypršení časového limitu u větších instalací, můžete namísto toho spustit následující příkaz v hlavním adresáři:",
+    "Detailed logs" : "Podrobné logy",
+    "Update needed" : "Potřeba aktualizace",
+    "Please use the command line updater because you have a big instance." : "Prosím použijte aktualizační příkazový řádek, protože máte velkou instanci.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Pro pomoc, shlédněte  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentaci</a>.",
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instalace %s je právě ve stavu údržby a to může chvíli trvat.",
-    "This page will refresh itself when the %s instance is available again." : "Tato stránka se automaticky načte poté, co bude opět dostupná instance %s.",
-    "Error loading file picker template: {error}" : "Chyba při nahrávání šablony výběru souborů: {error}",
-    "Password can not be changed. Please contact your administrator." : "Heslo nelze změnit. Kontaktujte prosím svého správce systému."
+    "This page will refresh itself when the %s instance is available again." : "Tato stránka se automaticky načte poté, co bude opět dostupná instance %s."
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
