@@ -1,25 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Tidak dapat mengirim Email ke pengguna berikut: %s",
-    "Preparing update" : "Mempersiapkan pembaruan",
-    "Turned on maintenance mode" : "Hidupkan mode perawatan",
-    "Turned off maintenance mode" : "Matikan mode perawatan",
-    "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
-    "Updating database schema" : "Memperbarui skema basis data",
-    "Updated database" : "Basis data terbaru",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema basis data dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
-    "Checked database schema update" : "Pembaruan skema basis data terperiksa",
-    "Checking updates of apps" : "Memeriksa pembaruan aplikasi",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema untuk %s dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
-    "Checked database schema update for apps" : "Pembaruan skema basis data terperiksa untuk aplikasi",
-    "Updated \"%s\" to %s" : "Terbaru \"%s\" sampai %s",
-    "Repair warning: " : "Peringatan perbaikan:",
-    "Repair error: " : "Kesalahan perbaikan:",
-    "%s (3rdparty)" : "%s (pihak ke-3)",
-    "%s (incompatible)" : "%s (tidak kompatibel)",
-    "Following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
-    "Already up to date" : "Sudah yang terbaru",
     "File is too big" : "Berkas terlalu besar",
     "Invalid file provided" : "Berkas yang diberikan tidak sah",
     "No image or file provided" : "Tidak ada gambar atau berkas yang disediakan",
@@ -35,6 +16,32 @@ OC.L10N.register(
     "Couldn't send reset email. Please make sure your username is correct." : "Tidak dapat menyetel ulang email. Mohon pastikan nama pengguna Anda benar.",
     "%s password reset" : "%s sandi disetel ulang",
     "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
+    "Error loading tags" : "Kesalahan saat saat memuat tag",
+    "Tag already exists" : "Tag sudah ada",
+    "Error deleting tag(s)" : "Kesalahan saat menghapus tag",
+    "Error tagging" : "Kesalahan saat memberikan tag",
+    "Error untagging" : "Kesalahan saat menghapus tag",
+    "Error favoriting" : "Kesalahan saat memberikan sebagai favorit",
+    "Error unfavoriting" : "Kesalahan saat menghapus sebagai favorit",
+    "Couldn't send mail to following users: %s " : "Tidak dapat mengirim Email ke pengguna berikut: %s",
+    "Preparing update" : "Mempersiapkan pembaruan",
+    "Repair warning: " : "Peringatan perbaikan:",
+    "Repair error: " : "Kesalahan perbaikan:",
+    "Turned on maintenance mode" : "Hidupkan mode perawatan",
+    "Turned off maintenance mode" : "Matikan mode perawatan",
+    "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
+    "Updating database schema" : "Memperbarui skema basis data",
+    "Updated database" : "Basis data terbaru",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema basis data dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
+    "Checked database schema update" : "Pembaruan skema basis data terperiksa",
+    "Checking updates of apps" : "Memeriksa pembaruan aplikasi",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema untuk %s dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
+    "Checked database schema update for apps" : "Pembaruan skema basis data terperiksa untuk aplikasi",
+    "Updated \"%s\" to %s" : "Terbaru \"%s\" sampai %s",
+    "%s (3rdparty)" : "%s (pihak ke-3)",
+    "%s (incompatible)" : "%s (tidak kompatibel)",
+    "Following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
+    "Already up to date" : "Sudah yang terbaru",
     "Sunday" : "Minggu",
     "Monday" : "Senin",
     "Tuesday" : "Selasa",
@@ -128,8 +135,6 @@ OC.L10N.register(
     "Expiration" : "Kedaluwarsa",
     "Expiration date" : "Tanggal kedaluwarsa",
     "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
-    "Sending ..." : "Mengirim ...",
-    "Email sent" : "Email terkirim",
     "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
     "Share link" : "Bagikan tautan",
     "Link" : "Tautan",
@@ -138,6 +143,8 @@ OC.L10N.register(
     "Allow editing" : "Izinkan penyuntingan",
     "Email link to person" : "Emailkan tautan ini ke orang",
     "Send" : "Kirim",
+    "Sending ..." : "Mengirim ...",
+    "Email sent" : "Email terkirim",
     "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
     "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
     "group" : "grup",
@@ -151,11 +158,8 @@ OC.L10N.register(
     "delete" : "hapus",
     "access control" : "kontrol akses",
     "Share details could not be loaded for this item." : "Rincian berbagi tidak dapat dimuat untuk item ini.",
-    "An error occured. Please try again" : "Terjadi masalah. Mohon coba kembali",
     "Share" : "Bagikan",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Bagikan dengan orang lain di ownCloud menggunakan sintaks username@example.com/owncloud",
-    "Share with users or groups …" : "Bagikan dengan pengguna atau grup ...",
-    "Share with users, groups or remote users …" : "Bagikan dengan pengguna, grup atau pengguna remote ...",
     "Warning" : "Peringatan",
     "Error while sending notification" : "Kesalahan ketika mengirim notifikasi",
     "Delete" : "Hapus",
@@ -173,10 +177,9 @@ OC.L10N.register(
     "Hello {name}" : "Helo {name}",
     "_download %n file_::_download %n files_" : ["unduh %n berkas"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
-    "Updating {productName} to version {version}, this may take a while." : "Memperbarui {productName} ke versi {version}, ini memerlukan waktu.",
     "An error occurred." : "Terjadi kesalahan.",
     "Please reload the page." : "Silakan muat ulang halaman.",
-    "The update was unsuccessful. " : "Pembaruan tidak berhasil.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Pembaruan gagal. Silakan laporkan masalah ini ke <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">komunitas ownCloud</a>.",
     "The update was successful. There were warnings." : "Pembaruan telah berhasil. Terdapat peringatan.",
     "The update was successful. Redirecting you to ownCloud now." : "Pembaruan sukses. Anda akan diarahkan ulang ke ownCloud.",
     "Searching other places" : "Mencari tempat lainnya",
@@ -187,13 +190,6 @@ OC.L10N.register(
     "Apps" : "Aplikasi",
     "Admin" : "Admin",
     "Help" : "Bantuan",
-    "Error loading tags" : "Kesalahan saat saat memuat tag",
-    "Tag already exists" : "Tag sudah ada",
-    "Error deleting tag(s)" : "Kesalahan saat menghapus tag",
-    "Error tagging" : "Kesalahan saat memberikan tag",
-    "Error untagging" : "Kesalahan saat menghapus tag",
-    "Error favoriting" : "Kesalahan saat memberikan sebagai favorit",
-    "Error unfavoriting" : "Kesalahan saat menghapus sebagai favorit",
     "Access forbidden" : "Akses ditolak",
     "File not found" : "Berkas tidak ditemukan",
     "The specified document has not been found on the server." : "Dokumen yang diminta tidak tersedia pada server.",
@@ -216,7 +212,6 @@ OC.L10N.register(
     "Trace" : "Jejak",
     "Security warning" : "Peringatan keamanan",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Untuk informasi cara mengkonfigurasi server anda dengan benar, silakan lihat <a href=\"%s\" target=\"_blank\">dokumentasi</a>.",
     "Create an <strong>admin account</strong>" : "Buat sebuah <strong>akun admin</strong>",
     "Username" : "Nama pengguna",
     "Storage & database" : "Penyimpanan & Basis data",
@@ -244,7 +239,6 @@ OC.L10N.register(
     "Search" : "Cari",
     "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
     "Please contact your administrator." : "Silahkan hubungi administrator anda.",
-    "An internal error occured." : "Terjadi kesalahan internal.",
     "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
     "Log in" : "Masuk",
     "Wrong password. Reset it?" : "Sandi salah. Atur ulang?",
@@ -270,9 +264,6 @@ OC.L10N.register(
     "Start update" : "Jalankan pembaruan",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
-    "This page will refresh itself when the %s instance is available again." : "Halaman ini akan disegarkan dengan sendiri saat instansi %s tersebut tersedia kembali.",
-    "Error loading file picker template: {error}" : "Kesalahan saat memuat templat berkas pemilih: {error}",
-    "Password can not be changed. Please contact your administrator." : "Sandi tidak dapat diubah. Silakan hubungi administrator Anda",
-    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Server ini tidak tersambung ke internet. Ini berarti beberapa fitur seperti me-mount penyimpanan eksternal, notifikasi pembaruan atau instalasi aplikasi pihak ketiga tidak akan bekerja. Mengakses berkas secara remote dan mengirim notifikasi email juga tidak bekerja. Kami menyarankan untuk mengaktifkan koneksi internet untuk server ini jika Anda ingin memiliki fitur ini."
+    "This page will refresh itself when the %s instance is available again." : "Halaman ini akan disegarkan dengan sendiri saat instansi %s tersebut tersedia kembali."
 },
 "nplurals=1; plural=0;");
