@@ -1,13 +1,13 @@
 OC.L10N.register(
     "core",
     {
+    "Unknown filetype" : "Nezināms datnes tips",
+    "Invalid image" : "Nederīgs attēls",
+    "%s password reset" : "%s paroles maiņa",
     "Couldn't send mail to following users: %s " : "Nevar nosūtīt epastu, sekojošiem lietotājiem: %s",
     "Turned on maintenance mode" : "Ieslēgts uzturēšanas režīms",
     "Turned off maintenance mode" : "Izslēgts uzturēšanas režīms",
     "Updated database" : "Atjaunota datu bāze",
-    "Unknown filetype" : "Nezināms datnes tips",
-    "Invalid image" : "Nederīgs attēls",
-    "%s password reset" : "%s paroles maiņa",
     "Sunday" : "Svētdiena",
     "Monday" : "Pirmdiena",
     "Tuesday" : "Otrdiena",
@@ -69,16 +69,16 @@ OC.L10N.register(
     "Error while sharing" : "Kļūda, daloties",
     "Error while unsharing" : "Kļūda, beidzot dalīties",
     "Error setting expiration date" : "Kļūda, iestatot termiņa datumu",
-    "Set expiration date" : "Iestaties termiņa datumu",
+    "Set expiration date" : "Iestatiet termiņa datumu",
     "Expiration date" : "Termiņa datums",
-    "Sending ..." : "Sūta...",
-    "Email sent" : "Vēstule nosūtīta",
     "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
     "Share link" : "Dalīt saiti",
     "Password protect" : "Aizsargāt ar paroli",
     "Password" : "Parole",
     "Email link to person" : "Sūtīt saiti personai pa e-pastu",
     "Send" : "Sūtīt",
+    "Sending ..." : "Sūta...",
+    "Email sent" : "Vēstule nosūtīta",
     "Shared with you and the group {group} by {owner}" : "{owner} dalījās ar jums un grupu {group}",
     "Shared with you by {owner}" : "{owner} dalījās ar jums",
     "group" : "grupa",
@@ -94,6 +94,7 @@ OC.L10N.register(
     "Rename" : "Pārsaukt",
     "The object type is not specified." : "Nav norādīts objekta tips.",
     "Add" : "Pievienot",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Atjaunināšana beidzās nesekmīgi. Lūdzu, ziņojiet par šo problēmu <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud kopienai</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "Atjaunināšana beidzās sekmīgi. Tagad pārsūta jūs uz ownCloud.",
     "Personal" : "Personīgi",
     "Users" : "Lietotāji",
@@ -102,7 +103,6 @@ OC.L10N.register(
     "Help" : "Palīdzība",
     "Access forbidden" : "Pieeja ir liegta",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Visticamāk, jūsu datu direktorija un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Vairāk informācijai kā konfigurēt serveri, lūdzu skatiet <a href=\"%s\" target=\"_blank\">dokumentāciju</a>.",
     "Create an <strong>admin account</strong>" : "Izveidot <strong>administratora kontu</strong>",
     "Username" : "Lietotājvārds",
     "Data folder" : "Datu mape",
