@@ -3,12 +3,13 @@ OC.L10N.register(
     {
     "Cannot write into \"config\" directory!" : "Запись в каталог \"config\" невозможна!",
     "This can usually be fixed by giving the webserver write access to the config directory" : "Обычно это можно исправить предоставив веб-серверу права на запись в каталоге конфигурации",
-    "See %s" : "Просмотр %s",
+    "See %s" : "Смотрите %s",
     "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Обычно это можно исправить %sпредоставив веб-серверу права на запись в каталоге конфигурации%s.",
     "Sample configuration detected" : "Обнаружена конфигурация из примера",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Была обнаружена конфигурация из примера. Такая конфигурация не поддерживается и может повредить вашей системе. Прочтите документацию перед внесением изменений в файл config.php",
     "PHP %s or higher is required." : "Требуется PHP %s или выше",
     "PHP with a version lower than %s is required." : "Требуется версия PHP ниже %s.",
+    "%sbit or higher PHP required." : "Требуется PHP с разрядностью %s бит или более.",
     "Following databases are supported: %s" : "Поддерживаются следующие СУБД: %s",
     "The command line tool %s could not be found" : "Утилита командной строки %s не найдена",
     "The library %s is not available." : "Библиотека %s недоступна.",
@@ -17,14 +18,6 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Поддерживаются следующие платформы: %s",
     "ownCloud %s or higher is required." : "Требуется ownCloud %s или выше.",
     "ownCloud %s or lower is required." : "Требуется ownCloud версии %s или ниже.",
-    "Help" : "Помощь",
-    "Personal" : "Личное",
-    "Users" : "Пользователи",
-    "Admin" : "Администрирование",
-    "Recommended" : "Рекомендовано",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Приложение \"%s\" не может быть установлено, так как оно не совместимо с этой версией ownCloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Приложение \"%s\" не может быть установлено, так как следующие зависимости не выполнены: %s",
-    "No app name specified" : "Не указано имя приложения",
     "Unknown filetype" : "Неизвестный тип файла",
     "Invalid image" : "Изображение повреждено",
     "today" : "сегодня",
@@ -37,18 +30,15 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n час назад","%n часа назад","%n часов назад","%n часов назад"],
     "_%n minute ago_::_%n minutes ago_" : ["%n минута назад","%n минуты назад","%n минут назад","%n минут назад"],
     "seconds ago" : "менее минуты",
-    "web services under your control" : "веб-сервисы под вашим управлением",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль с ID %s не существует. Пожалуйста включите его в настройках приложений или обратитесь к администратору.",
-    "Empty filename is not allowed" : "Пустые имена файлов не допускаются",
+    "Empty filename is not allowed" : "Пустое имя файла не допускается",
     "Dot files are not allowed" : "Файлы начинающиеся с точки не допускаются",
     "4-byte characters are not supported in file names" : "4-х байтовые символы в имени файлов не допускаются",
     "File name is a reserved word" : "Имя файла является зарезервированным словом",
     "File name contains at least one invalid character" : "Имя файла содержит по крайней мере один некорректный символ",
     "File name is too long" : "Имя файла слишком длинное.",
-    "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
-    "Can't read file" : "Не удается прочитать файл",
     "App directory already exists" : "Каталог приложения уже существует",
-    "Can't create app folder. Please fix permissions. %s" : "Не удалось создать каталог. Исправьте права доступа. %s",
+    "Can't create app folder. Please fix permissions. %s" : "Не удалось создать каталог приложения. Исправьте права доступа. %s",
     "Archive does not contain a directory named %s" : "Архив не содержит папки с именем %s",
     "No source specified when installing app" : "Не указан источник при установке приложения",
     "No href specified when installing app from http" : "Не указан атрибут href при установке приложения через http",
@@ -56,15 +46,13 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Архивы %s не поддерживаются",
     "Failed to open archive when installing app" : "Ошибка открытия архива при установке приложения",
     "App does not provide an info.xml file" : "Приложение не имеет файла info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "Приложение не может быть установлено, так как файл с информацией о приложении не может быть прочтен.",
     "Signature could not get checked. Please contact the app developer and check your admin screen." : "Подпись не может быть проверена. Пожалуйста, свяжитесь с разработчиком приложения и проверьте свою страницу администратора.",
     "App can't be installed because of not allowed code in the App" : "Приложение невозможно установить. В нем содержится запрещенный код.",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Приложение невозможно установить. Не совместимо с текущей версией ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Приложение невозможно установить. Оно содержит параметр <shipped>true</shipped> который не допустим для приложений, не входящих в поставку.",
     "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Приложение невозможно установить. Версия в файле info.xml не совпадает с версией заявленной в магазине приложений",
-    "Application is not enabled" : "Приложение не разрешено",
-    "Authentication error" : "Ошибка аутентификации",
-    "Token expired. Please reload page." : "Токен просрочен. Перезагрузите страницу.",
-    "Unknown user" : "Неизвестный пользователь",
+    "%s enter the database username and name." : "%s укажите имя пользователя и название для базы данных.",
     "%s enter the database username." : "%s введите имя пользователя базы данных.",
     "%s enter the database name." : "%s введите имя базы данных.",
     "%s you may not use dots in the database name" : "%s Вы не можете использовать точки в имени базы данных",
@@ -77,27 +65,27 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Неверное имя пользователя и/или пароль PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не поддерживается и %s может работать некорректно на данной платформе. Используйте на свой страх и риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной PHP среде и open_basedir должен быть настроен в php.ini. Это приведет к проблемам с файлами более 4 ГБ и это настоятельно не рекомендуется.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Удалите директиву open_basedir из файла php.ini или смените PHP на 64х разрядную сборку.",
-    "Set an admin username." : "Задать имя пользователя для admin.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Пожалуйста, удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
+    "Set an admin username." : "Задать имя пользователя для администратора.",
     "Set an admin password." : "Задать пароль для admin.",
     "Can't create or write into the data directory %s" : "Невозможно создать или записать в каталог данных %s",
     "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
     "%s shared »%s« with you" : "%s поделился »%s« с вами",
     "%s via %s" : "%s через %s",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Не удалось поделиться %s, общий доступ не допускает публикации из элементов типа %i",
+    "Sharing %s failed, because the backend does not allow shares from type %i" : "Не удалось поделиться %s, так как механизм хранения не допускает публикации из элементов типа %i",
     "Sharing %s failed, because the file does not exist" : "Не удалось поделиться %s, файл не существует",
-    "You are not allowed to share %s" : "Вам запрещено делиться %s",
+    "You are not allowed to share %s" : "Вам не разрешено делиться %s",
     "Sharing %s failed, because you can not share with yourself" : "Не удалось поделиться %s. Вы не можете поделиться с самим собой.",
     "Sharing %s failed, because the user %s does not exist" : "Не удалось поделиться %s, пользователь %s не существует.",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Не удалось поделиться %s, пользователь %s не состоит в какой-либо группе в которой состоит %s",
+    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Не удалось поделиться %s, так как пользователь %s не состоит в какой-либо группе, в которой состоит %s",
     "Sharing %s failed, because this item is already shared with %s" : "Не удалось поделиться %s, пользователь %s уже имеет доступ к этому элементу",
     "Sharing %s failed, because this item is already shared with user %s" : "Не удалось поделиться %s, так как элемент находится в общем доступе у %s",
     "Sharing %s failed, because the group %s does not exist" : "Не удалось поделиться %s, группа %s не существует",
     "Sharing %s failed, because %s is not a member of the group %s" : "Не удалось поделиться %s, пользователь %s не является членом группы %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Вам нужно задать пароль для создания публичной ссылки. Разрешены только защищённые ссылки",
     "Sharing %s failed, because sharing with links is not allowed" : "Не удалось поделиться %s, открытие доступа по ссылке запрещено",
-    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем-же пользователем",
+    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Не удалось поделиться %s, не удалось найти %s, возможно, сервер не доступен.",
     "Share type %s is not valid for %s" : "Тип общего доступа %s недопустим для %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Не удалось настроить права доступа для %s, указанные права доступа превышают предоставленные для %s",
@@ -114,23 +102,43 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Не удалось поделиться %s, бэкенд общего доступа не нашел путь до %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Не удалось поделиться %s, элемент не найден в файловом кеше.",
     "Cannot increase permissions of %s" : "Невозможно увеличить права доступа для %s",
+    "Files can't be shared with delete permissions" : "Файлы не могут иметь общий доступ с правами на удаление",
+    "Files can't be shared with create permissions" : "Файлы не могут иметь общий доступ с правами на создание",
     "Expiration date is in the past" : "Дата окончания срока действия уже прошла",
     "Cannot set expiration date more than %s days in the future" : "Невозможно установить дату окончания срока действия более %s дней",
     "Could not find category \"%s\"" : "Категория \"%s\"  не найдена",
     "Apps" : "Приложения",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "В качестве имени пользователя допускаются следующие символы: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
-    "A valid username must be provided" : "Укажите правильное имя пользователя",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "В составе имени пользователя допускаются следующие символы: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
+    "A valid username must be provided" : "Укажите допустимое имя пользователя",
     "Username contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробел в начале или в конце",
-    "A valid password must be provided" : "Укажите правильный пароль",
+    "A valid password must be provided" : "Укажите допустимый пароль",
     "The username is already being used" : "Имя пользователя уже используется",
+    "Login canceled by app" : "Вход отменен приложением",
+    "User disabled" : "Пользователь отключен",
+    "Help" : "Помощь",
+    "Personal" : "Личное",
+    "Users" : "Пользователи",
+    "Admin" : "Администрирование",
+    "Recommended" : "Рекомендовано",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Приложение \"%s\" не может быть установлено, так как файл с информацией о приложении не может быть прочтен.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Приложение \"%s\" не может быть установлено, так как оно не совместимо с этой версией ownCloud.",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Приложение \"%s\" не может быть установлено, так как следующие зависимости не выполнены: %s",
+    "No app name specified" : "Не указано имя приложения",
+    "web services under your control" : "веб-сервисы под вашим управлением",
+    "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
+    "Can't read file" : "Не удается прочитать файл",
+    "Application is not enabled" : "Приложение не разрешено",
+    "Authentication error" : "Ошибка аутентификации",
+    "Token expired. Please reload page." : "Токен просрочен. Перезагрузите страницу.",
+    "Unknown user" : "Неизвестный пользователь",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Не установлены драйвера баз данных (sqlite, mysql или postgresql)",
     "Microsoft Windows Platform is not supported" : "Платформа Microsoft Windows не поддерживается",
-    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Установка ownCloud на платформе Microsoft Windows Server не поддерживается. Мы рекомендуем использовать сервер на базе ядра Linux, если-же замена ОС на сервере не возможна, рекомендуется установить Linux-сервер на виртуальную машину. Пакеты для Linux, а так-же легко развертываемый образ виртуальной машины можно найти <a href=\"%s\">%s</a>. Скрипты и советы для миграции существующих серверов на Linux вы можете найти в <a href=\"%s\">нашей документации</a>.",
+    "Running ownCloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Запуск ownCloud на платформе Microsoft Windows Server не поддерживается. Мы рекомендуем использовать сервер на базе Linux в виртуальной машине, если замена ОС на сервере не возможна. Пакеты для Linux, а также легко развертываемый образ виртуальной машины можно найти <a href=\"%s\">%s</a>. Скрипты и советы для миграции существующих серверов на Linux вы можете найти в <a href=\"%s\">нашей документации</a>.",
     "Cannot write into \"config\" directory" : "Запись в каталог \"config\" невозможна",
     "Cannot write into \"apps\" directory" : "Запись в каталог \"app\" невозможна",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Обычно это можно исправить, %sпредоставив веб-серверу права на запись в каталог приложений%s или отключив хранилище программ в файле конфигурации.",
+    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Обычно это можно исправить, %sпредоставив веб-серверу права на запись в каталог приложений%s или отключив магазин приложений в файле конфигурации.",
     "Cannot create \"data\" directory (%s)" : "Невозможно создать каталог \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Обычно это можно исправить, <a href=\"%s\" target=\"_blank\">предоставив веб-серверу права на запись в корневом каталоге.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Обычно это можно исправить <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">предоставив веб-серверу права на запись в корневом каталоге</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Обычно это можно исправить, %sпредоставив веб-серверу права на запись в корневой каталог%s.",
     "Setting locale to %s failed" : "Установка локали %s не удалась",
     "Please install one of these locales on your system and restart your webserver." : "Установите один из этих языковых пакетов на вашу систему и перезапустите веб-сервер.",
@@ -140,6 +148,8 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Установка этого параметра в php.ini позволит запуститься ownCloud снова.",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload установлен в \"%s\", при этом требуется \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Чтобы исправить эту проблему установите параметр <code>mbstring.func_overload</code> в значение <code>0</code> в php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Требуется как минимум libxml2 версии 2.7.0. На данный момент установлена %s.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Для исправления этой ошибки обновите версию libxml2 и перезапустите ваш веб-сервер.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Очевидно, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Модули PHP были установлены, но они все еще перечислены как недостающие?",
@@ -148,7 +158,7 @@ OC.L10N.register(
     "Please upgrade your database version" : "Обновите базу данных",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Измените права доступа на 0770, чтобы другие пользователи не могли получить список файлов этого каталога.",
     "Data directory (%s) is readable by other users" : "Каталог данных (%s) доступен для чтения другим пользователям",
-    "Data directory (%s) must be an absolute path" : "Директория данных (%s) должна иметь абсолютный путь",
+    "Data directory (%s) must be an absolute path" : "Каталог данных (%s) должен быть абсолютным путём",
     "Check the value of \"datadirectory\" in your configuration" : "Проверьте значение \"datadirectory\" в настройках.",
     "Data directory (%s) is invalid" : "Каталог данных (%s) не верен",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Убедитесь, что файл \".ocdata\" присутствует в корне каталога данных.",
