@@ -45,6 +45,7 @@
  *
  */
 use OC\App\DependencyAnalyzer;
+use OC\App\InfoParser;
 use OC\App\Platform;
 use OC\Installer;
 use OC\OCSClient;
@@ -327,6 +328,13 @@ class OC_App {
 		self::$enabledAppsCache = array(); // flush
 		if (!Installer::isInstalled($app)) {
 			$app = self::installApp($app);
+		} else {
+			// check for required dependencies
+			$config = \OC::$server->getConfig();
+			$l = \OC::$server->getL10N('core');
+			$info = self::getAppInfo($app);
+
+			self::checkAppDependencies($config, $l, $info);
 		}
 
 		$appManager = \OC::$server->getAppManager();
@@ -658,7 +666,7 @@ class OC_App {
 			$file = $appPath . '/appinfo/info.xml';
 		}
 
-		$parser = new \OC\App\InfoParser(\OC::$server->getURLGenerator());
+		$parser = new InfoParser();
 		$data = $parser->parse($file);
 
 		if (is_array($data)) {
@@ -821,6 +829,7 @@ class OC_App {
 		//we don't want to show configuration for these
 		$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
 		$appList = array();
+		$urlGenerator = \OC::$server->getURLGenerator();
 
 		foreach ($installedApps as $app) {
 			if (array_search($app, $blacklist) === false) {
@@ -874,6 +883,19 @@ class OC_App {
 						}
 					}
 				}
+				// fix documentation
+				if (isset($info['documentation']) && is_array($info['documentation'])) {
+					foreach ($info['documentation'] as $key => $url) {
+						// If it is not an absolute URL we assume it is a key
+						// i.e. admin-ldap will get converted to go.php?to=admin-ldap
+						if (stripos($url, 'https://') !== 0 && stripos($url, 'http://') !== 0) {
+							$url = $urlGenerator->linkToDocs($url);
+						}
+
+						$info['documentation'][$key] = $url;
+					}
+				}
+
 				$info['version'] = OC_App::getAppVersion($app);
 				$appList[] = $info;
 			}
@@ -1144,16 +1166,7 @@ class OC_App {
 			}
 
 			// check for required dependencies
-			$dependencyAnalyzer = new DependencyAnalyzer(new Platform($config), $l);
-			$missing = $dependencyAnalyzer->analyze($info);
-			if (!empty($missing)) {
-				$missingMsg = join(PHP_EOL, $missing);
-				throw new \Exception(
-					$l->t('App "%s" cannot be installed because the following dependencies are not fulfilled: %s',
-						array($info['name'], $missingMsg)
-					)
-				);
-			}
+			self::checkAppDependencies($config, $l, $info);
 
 			$config->setAppValue($app, 'enabled', 'yes');
 			if (isset($appData['id'])) {
@@ -1320,4 +1333,23 @@ class OC_App {
 
 		return $data;
 	}
+
+	/**
+	 * @param $config
+	 * @param $l
+	 * @param $info
+	 * @throws Exception
+	 */
+	protected static function checkAppDependencies($config, $l, $info) {
+		$dependencyAnalyzer = new DependencyAnalyzer(new Platform($config), $l);
+		$missing = $dependencyAnalyzer->analyze($info);
+		if (!empty($missing)) {
+			$missingMsg = join(PHP_EOL, $missing);
+			throw new \Exception(
+				$l->t('App "%s" cannot be installed because the following dependencies are not fulfilled: %s',
+					[$info['name'], $missingMsg]
+				)
+			);
+		}
+	}
 }
