@@ -1,9 +1,9 @@
 <?php
 /**
- * @author Björn Schießle <schiessle@owncloud.com>
+ * @author Björn Schießle <bjoern@schiessle.org>
  * @author Christopher Schäpers <kondou@ts.unde.re>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
- * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Robin Appelman <icewind@owncloud.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
@@ -49,7 +49,7 @@ try {
 		$pathInfo = trim($pathInfo, '/');
 		list($service) = explode('/', $pathInfo);
 	}
-	$file = OCP\CONFIG::getAppValue('core', 'public_' . strip_tags($service));
+	$file = OCP\Config::getAppValue('core', 'public_' . strip_tags($service));
 	if (is_null($file)) {
 		header('HTTP/1.0 404 Not Found');
 		exit;
@@ -73,14 +73,18 @@ try {
 
 	require_once OC_App::getAppPath($app) . '/' . $parts[1];
 
-} catch (\OC\ServiceUnavailableException $ex) {
-	//show the user a detailed error page
-	OC_Response::setStatus(OC_Response::STATUS_SERVICE_UNAVAILABLE);
-	\OCP\Util::writeLog('remote', $ex->getMessage(), \OCP\Util::FATAL);
-	OC_Template::printExceptionErrorPage($ex);
 } catch (Exception $ex) {
+	if ($ex instanceof \OC\ServiceUnavailableException) {
+		OC_Response::setStatus(OC_Response::STATUS_SERVICE_UNAVAILABLE);
+	} else {
+		OC_Response::setStatus(OC_Response::STATUS_INTERNAL_SERVER_ERROR);
+	}
+	//show the user a detailed error page
+	\OC::$server->getLogger()->logException($ex, ['app' => 'public']);
+	OC_Template::printExceptionErrorPage($ex);
+} catch (Error $ex) {
 	//show the user a detailed error page
 	OC_Response::setStatus(OC_Response::STATUS_INTERNAL_SERVER_ERROR);
-	\OCP\Util::writeLog('remote', $ex->getMessage(), \OCP\Util::FATAL);
+	\OC::$server->getLogger()->logException($ex, ['app' => 'public']);
 	OC_Template::printExceptionErrorPage($ex);
 }
