@@ -1,18 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "Sharing" : "مشاركة",
-    "Cron" : "مجدول",
-    "Log" : "سجل",
-    "Language changed" : "تم تغيير اللغة",
-    "Invalid request" : "طلب غير مفهوم",
-    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
-    "Admins can't remove themself from the admin group" : "لا يستطيع المدير إزالة حسابه من مجموعة المديرين",
-    "Unable to add user to group %s" : "فشل إضافة المستخدم الى المجموعة %s",
-    "Unable to remove user from group %s" : "فشل إزالة المستخدم من المجموعة %s",
-    "Couldn't update app." : "تعذر تحديث التطبيق.",
     "Wrong password" : "كلمة مرور خاطئة",
     "No user supplied" : "لم يتم توفير مستخدم ",
+    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "يرجى توفير كلمة مرور المسؤول المستردة, وإلا سيتم فقد جميع بيانات المستخدم ",
     "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
     "Unable to change password" : "لا يمكن تغيير كلمة المرور",
@@ -23,6 +14,15 @@ OC.L10N.register(
     "Email saved" : "تم حفظ البريد الإلكتروني",
     "Your full name has been changed." : "اسمك الكامل تم تغييره.",
     "Unable to change full name" : "لم يتم التمكن من تغيير اسمك الكامل",
+    "Sharing" : "مشاركة",
+    "Cron" : "مجدول",
+    "Log" : "سجل",
+    "Language changed" : "تم تغيير اللغة",
+    "Invalid request" : "طلب غير مفهوم",
+    "Admins can't remove themself from the admin group" : "لا يستطيع المدير إزالة حسابه من مجموعة المديرين",
+    "Unable to add user to group %s" : "فشل إضافة المستخدم الى المجموعة %s",
+    "Unable to remove user from group %s" : "فشل إزالة المستخدم من المجموعة %s",
+    "Couldn't update app." : "تعذر تحديث التطبيق.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "هل أنت متأكد انك تريد إضافة \"{domain}\" كنطاق موثوق فيه.",
     "Sending..." : "جاري الارسال ...",
     "All" : "الكل",
@@ -49,6 +49,7 @@ OC.L10N.register(
     "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
     "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
     "__language_name__" : "__language_name__",
+    "Unlimited" : "غير محدود",
     "Everything (fatal issues, errors, warnings, info, debug)" : "كل شيء (مشاكل فادحة, اخطاء , تحذيرات , معلومات , تصحيح الاخطاء)",
     "Info, warnings, errors and fatal issues" : "معلومات , تحذيرات , اخطاء , مشاكل فادحة ",
     "Warnings, errors and fatal issues" : "تحذيرات , اخطاء , مشاكل فادحة ",
@@ -92,9 +93,11 @@ OC.L10N.register(
     "Change password" : "عدل كلمة السر",
     "Language" : "اللغة",
     "Help translate" : "ساعد في الترجمه",
+    "Name" : "الاسم",
+    "Username" : "إسم المستخدم",
     "Get the apps to sync your files" : "احصل على التطبيقات لمزامنة ملفاتك",
     "Show First Run Wizard again" : "ابدأ خطوات بداية التشغيل من جديد",
-    "Username" : "إسم المستخدم",
+    "E-Mail" : "بريد إلكتروني",
     "Create" : "انشئ",
     "Admin Recovery Password" : "استعادة كلمة المرور للمسؤول",
     "Enter the recovery password in order to recover the users files during password change" : "ادخل كلمة المرور المستعادة من اجل استرداد ملفات المستخدمين اثناء تغيير كلمة المرور",
@@ -102,7 +105,6 @@ OC.L10N.register(
     "Everyone" : "الجميع",
     "Default Quota" : "الحصة النسبية الإفتراضية",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "يرجى ادخال تخزين quota (مثل:\"512 MB\" او  \"12 GB\")",
-    "Unlimited" : "غير محدود",
     "Other" : "شيء آخر",
     "Full Name" : "اسمك الكامل",
     "Quota" : "حصه",
