@@ -1,33 +1,16 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Avisos de seguretat i configuració",
-    "Sharing" : "Compartir",
-    "Server-side encryption" : "Xifrat del costat del servidor",
-    "External Storage" : "Emmagatzemament extern",
-    "Cron" : "Cron",
-    "Email server" : "Servidor de correu electrònic",
-    "Log" : "Registre",
-    "Tips & tricks" : "Consells i trucs",
-    "Updates" : "Actualitzacions",
-    "Couldn't remove app." : "No s'ha pogut eliminar l'aplicació",
-    "Language changed" : "S'ha canviat l'idioma",
-    "Invalid request" : "Sol·licitud no vàlida",
-    "Authentication error" : "Error d'autenticació",
-    "Admins can't remove themself from the admin group" : "Els administradors no es poden eliminar del grup admin",
-    "Unable to add user to group %s" : "No es pot afegir l'usuari al grup %s",
-    "Unable to remove user from group %s" : "No es pot eliminar l'usuari del grup %s",
-    "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
     "Wrong password" : "Contrasenya incorrecta",
     "No user supplied" : "No heu proporcionat cap usuari",
+    "Authentication error" : "Error d'autenticació",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Sisplau, proporcioneu una contrasenya de recuperació d'administrador, altrament totes les dades d'usuari es perdran",
     "Wrong admin recovery password. Please check the password and try again." : "La contrasenya de recuperació d'administrador és incorrecta. Comproveu-la i torneu-ho a intentar.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "El backend no admet canvis de contrasenya, però la clau de xifrat de l'usuari ha estat actualitzada satisfactòriament.",
     "Unable to change password" : "No es pot canviar la contrasenya",
     "Enabled" : "Activat",
     "Not enabled" : "Desactivat",
+    "Federated Cloud Sharing" : "Compartició federada de núvol",
     "A problem occurred, please check your log files (Error: %s)" : "S'ha produït un problema, si us plau revisi els arxius de registre (Error: %s)",
     "Migration Completed" : "Migració completada",
     "Group already exists." : "El grup ja existeix.",
@@ -50,6 +33,24 @@ OC.L10N.register(
     "Email saved" : "S'ha desat el correu electrònic",
     "Your full name has been changed." : "El vostre nom complet ha canviat.",
     "Unable to change full name" : "No s'ha pogut canviar el nom complet",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Avisos de seguretat i configuració",
+    "Sharing" : "Compartir",
+    "Server-side encryption" : "Xifrat del costat del servidor",
+    "External Storage" : "Emmagatzemament extern",
+    "Cron" : "Cron",
+    "Email server" : "Servidor de correu electrònic",
+    "Log" : "Registre",
+    "Tips & tricks" : "Consells i trucs",
+    "Updates" : "Actualitzacions",
+    "Couldn't remove app." : "No s'ha pogut eliminar l'aplicació",
+    "Language changed" : "S'ha canviat l'idioma",
+    "Invalid request" : "Sol·licitud no vàlida",
+    "Admins can't remove themself from the admin group" : "Els administradors no es poden eliminar del grup admin",
+    "Unable to add user to group %s" : "No es pot afegir l'usuari al grup %s",
+    "Unable to remove user from group %s" : "No es pot eliminar l'usuari del grup %s",
+    "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Esteu seguir que voleu afegir \"{domain}\" com a un domini de confiança?",
     "Add trusted domain" : "Afegir domini de confiança",
     "Migration in progress. Please wait until the migration is finished" : "Migració en progrés. Si us plau, espereu fins que finalitzi la migració",
@@ -95,6 +96,7 @@ OC.L10N.register(
     "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
     "A valid email must be provided" : "S'ha de subministrar una adreça de correu electrònic vàlida",
     "__language_name__" : "Català",
+    "Unlimited" : "Il·limitat",
     "Personal info" : "Informació personal",
     "Sync clients" : "Sincronitzar clients",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tot (problemes fatals, errors, avisos, informació, depuració)",
@@ -118,14 +120,13 @@ OC.L10N.register(
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Recomanem fermament que instal·leu els paquets requerits en el vostre sistema per suportar un dels següents idiomes: %s",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Si la seva instal·lació no està situada en l'arrel del domini i usa el sistema cron, pot haver-hi problemes en generar-se els URL. Per evitar-los, configuri l'opció \"overwrite.cli.url\" en el seu arxiu config.php perquè usi la ruta de l'arrel del lloc web de la seva instal·lació (suggeriment: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "No va ser possible executar cronjob via CLI. Han aparegut els següents errors tècnics:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Per favor, torni a comprovar les <a target=\"_blank\" href=\"%s\">guies d'instal·lació ↗ </a>, i verifiqui que no existeixen errors o advertiments en el <a href=\"#log-section\">log</a>.",
     "Open documentation" : "Obre la documentació",
     "Allow apps to use the Share API" : "Permet que les aplicacions utilitzin l'API de compartir",
     "Allow users to share via link" : "Permet als usuaris compartir a través d'enllaços",
-    "Enforce password protection" : "Reforça la protecció amb contrasenya",
     "Allow public uploads" : "Permet pujada pública",
-    "Allow users to send mail notification for shared files" : "Permet als usuaris enviar notificacions de fitxers compartits per correu ",
+    "Enforce password protection" : "Reforça la protecció amb contrasenya",
     "Set default expiration date" : "Estableix la data de venciment",
+    "Allow users to send mail notification for shared files" : "Permet als usuaris enviar notificacions de fitxers compartits per correu ",
     "Expire after " : "Venciment després de",
     "days" : "dies",
     "Enforce expiration date" : "Força la data de venciment",
@@ -164,7 +165,6 @@ OC.L10N.register(
     "The logfile is bigger than 100 MB. Downloading it may take some time!" : "L'arxiu de registre és més gran de 100 MB. La descàrrega pot trigar!",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "S'utilitza SQLite com a base de dades. Per a instal·lacions mes grans es recomana canviar a un altre sistema de base de dades.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'ús de SQLite està desaconsellat especialment quan s'usa el client d'escriptori per sincronitzar els fitxers.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Per migrar a una altra base de dades utilitzar la interfície de línia de comandes: 'occ db:convert-type', o veure la <a target=\"_blank\" href=\"%s\">documentació ↗</a>.",
     "How to do backups" : "Com fer còpies de seguretat",
     "Advanced monitoring" : "Supervisió avançada",
     "Performance tuning" : "Ajust del rendiment",
@@ -210,6 +210,8 @@ OC.L10N.register(
     "Change password" : "Canvia la contrasenya",
     "Language" : "Idioma",
     "Help translate" : "Ajudeu-nos amb la traducció",
+    "Name" : "Nom",
+    "Username" : "Nom d'usuari",
     "Get the apps to sync your files" : "Obtingueu les aplicacions per sincronitzar els vostres fitxers",
     "Desktop client" : "Client d'escriptori",
     "Android app" : "aplicació para Android",
@@ -222,7 +224,6 @@ OC.L10N.register(
     "Show user backend" : "Mostrar backend d'usuari",
     "Send email to new user" : "Enviar correu electrònic al nou usuari",
     "Show email address" : "Mostrar l'adreça de correu electrònic",
-    "Username" : "Nom d'usuari",
     "E-Mail" : "E-mail",
     "Create" : "Crea",
     "Admin Recovery Password" : "Recuperació de contrasenya d'administrador",
@@ -233,7 +234,6 @@ OC.L10N.register(
     "Admins" : "Administradors",
     "Default Quota" : "Quota per defecte",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Escriviu la quota d'emmagatzemament (per ex.: \"512 MB\" o \"12 GB\")",
-    "Unlimited" : "Il·limitat",
     "Other" : "Un altre",
     "Full Name" : "Nom complet",
     "Group Admin for" : "Grup Admin per",
