@@ -1,27 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
-    "Sharing" : "Deling",
-    "Server-side encryption" : "Serverkryptering",
-    "External Storage" : "Ekstern lagring",
-    "Cron" : "Cron",
-    "Email server" : "E-postserver",
-    "Log" : "Logg",
-    "Tips & tricks" : "Tips og triks",
-    "Updates" : "Oppdateringer",
-    "Couldn't remove app." : "Klarte ikke å fjerne app.",
-    "Language changed" : "Språk endret",
-    "Invalid request" : "Ugyldig forespørsel",
-    "Authentication error" : "Autentiseringsfeil",
-    "Admins can't remove themself from the admin group" : "Admin kan ikke flytte seg selv fra admingruppen",
-    "Unable to add user to group %s" : "Kan ikke legge bruker til gruppen %s",
-    "Unable to remove user from group %s" : "Kan ikke slette bruker fra gruppen %s",
-    "Couldn't update app." : "Kunne ikke oppdatere app.",
     "Wrong password" : "Feil passord",
     "No user supplied" : "Ingen bruker angitt",
+    "Authentication error" : "Autentiseringsfeil",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Vennligst oppgi et administrativt gjenopprettingspassord. Ellers vil alle brukerdata gå tapt",
     "Wrong admin recovery password. Please check the password and try again." : "Feil administrativt gjenopprettingspassord. Sjekk passordet og prøv igjen.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Serveren støtter ikke endring av passord, men oppdatering av brukerens krypteringsnøkkel var vellykket.",
@@ -53,8 +35,26 @@ OC.L10N.register(
     "Email saved" : "Epost lagret",
     "Your full name has been changed." : "Ditt fulle navn er blitt endret.",
     "Unable to change full name" : "Klarte ikke å endre fullt navn",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ønsker du virkelig å legge til \"{domain}\" som tiltrodd domene?",
-    "Add trusted domain" : "Legg til et tiltrodd domene",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
+    "Sharing" : "Deling",
+    "Server-side encryption" : "Serverkryptering",
+    "External Storage" : "Ekstern lagring",
+    "Cron" : "Cron",
+    "Email server" : "E-postserver",
+    "Log" : "Logg",
+    "Tips & tricks" : "Tips og triks",
+    "Updates" : "Oppdateringer",
+    "Couldn't remove app." : "Klarte ikke å fjerne app.",
+    "Language changed" : "Språk endret",
+    "Invalid request" : "Ugyldig forespørsel",
+    "Admins can't remove themself from the admin group" : "Admin kan ikke flytte seg selv fra admingruppen",
+    "Unable to add user to group %s" : "Kan ikke legge bruker til gruppen %s",
+    "Unable to remove user from group %s" : "Kan ikke slette bruker fra gruppen %s",
+    "Couldn't update app." : "Kunne ikke oppdatere app.",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ønsker du virkelig å legge til \"{domain}\" som klarert domene?",
+    "Add trusted domain" : "Legg til et klarert domene",
     "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til migreringen er ferdig.",
     "Migration started …" : "Migrering startet ..",
     "Sending..." : "Sender...",
@@ -63,8 +63,9 @@ OC.L10N.register(
     "Experimental" : "Eksperimentell",
     "All" : "Alle",
     "No apps found for your version" : "Ingen apper funnet for din versjon",
+    "The app will be downloaded from the app store" : "Appen vil bli lastet ned fra app-butikken",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Offisielle apper utvikles av og innenfor ownCloud-fellesskapet. De tilbyr funksjonalitet som er sentral for ownCloud og er forberedt for produksjonsbruk.",
-    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Godkjente apper er utviklet av pålitelige utviklere og har gjennomgått en rask sikkerhetssjekk. De vedlikeholdes aktivt i et åpent kode-depot og utviklerne anser dem for å være stabile for tidvis eller normal bruk.",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Godkjente apper er utviklet av tiltrodde utviklere og har gjennomgått en rask sikkerhetssjekk. De vedlikeholdes aktivt i et åpent kode-depot og utviklerne anser dem for å være stabile for tidvis eller normal bruk.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Denne appen er ikke sjekket for sikkerhetsproblemer og er ny eller ansett for å være ustabil. Installer på egen risiko.",
     "Update to %s" : "Oppdater til %s",
     "_You have %n app update pending_::_You have %n app updates pending_" : ["Du har %n app-oppdatering som venter","Du har %n app-oppdateringer som venter"],
@@ -73,6 +74,9 @@ OC.L10N.register(
     "Disable" : "Deaktiver ",
     "Enable" : "Aktiver",
     "Error while enabling app" : "Aktivering av app feilet",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Feil: Denne appen kan ikke aktiveres fordi den gjør serveren ustabil",
+    "Error: could not disable broken app" : "Feil: Kunne ikke deaktivere ustabil app",
+    "Error while disabling broken app" : "Feil ved deaktivering av ustabil app",
     "Updating...." : "Oppdaterer...",
     "Error while updating app" : "Feil ved oppdatering av app",
     "Updated" : "Oppdatert",
@@ -81,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Avinstaller",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er aktivert men må oppdateres. Du vil bli omdirigert til oppdateringssiden om 5 sekunder.",
     "App update" : "Oppdatering av applikasjon",
-    "No apps found for \"{query}\"" : "Ingen apper funnet for \"{query}\"",
+    "No apps found for {query}" : "Ingen apper funnet for \"{query}\"",
+    "Disconnect" : "Koble fra",
+    "Error while loading browser sessions and device tokens" : "Feil ved lasting av nettleser-økter og enhetsnøkler",
+    "Error while creating device token" : "Feil ved oppretting av enhetsnøkkel",
+    "Error while deleting the token" : "Feil ved sletting av nøkkelen",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Det oppstod en feil. Vennligst last opp et ASCII-kodet PEM-sertifikat.",
     "Valid until {date}" : "Gyldig til {date}",
     "Delete" : "Slett",
@@ -108,7 +116,10 @@ OC.L10N.register(
     "A valid password must be provided" : "Oppgi et gyldig passord",
     "A valid email must be provided" : "En gyldig e-postadresse må oppgis",
     "__language_name__" : "__language_name__",
+    "Unlimited" : "Ubegrenset",
     "Personal info" : "Personlig informasjon",
+    "Sessions" : "Økter",
+    "App passwords" : "App-passord",
     "Sync clients" : "Synkroniseringsklienter",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Alt (fatale problemer, feil, advarsler, info, debug)",
     "Info, warnings, errors and fatal issues" : "Info, advarsler, feil og fatale problemer",
@@ -122,32 +133,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ser ikke ut til å være satt opp riktig for å lese systemets miljøvariabler. Testen med getenv(\"PATH\") returnerer bare et tomt svar.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Sjekk <a target=\"_blank\" href=\"%s\">installasjonsdokumentasjonen ↗</a> for notiser om PHP-konfigurering og om konfigurering av serveren, spesielt ved bruk av php-fpm.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Vennligst sjekk <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installasjonsdokumentasjonen ↗</a> etter php konfigurasjonsnotater og konfigurering av php på serveren din, særlig om du bruker php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Den skrivebeskyttede konfigurasjonen er blitt aktivert. Dette forhindrer setting av visse konfigureringer via web-grensesnittet. Videre må config-filen gjøres skrivbar manuelt for hver oppdatering.",
     "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut for at PHP er satt opp til å fjerne innebygde doc blocks. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av en bufrer/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Databasen din kjører ikke med transaksjonsisoleringsnivå \"READ COMMITED\". Dette kan føre til problemer når flere handlinger kjøres parallelt.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Serveren din kjører på Microsoft Windows. Vi anbefaler strekt Linux for en optimal brukeropplevelse.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s lavere enn versjon %2$s er installert. Vi anbefaler å oppgradere til en nyere %1$s-versjon for å få bedre stabilitet og ytelse.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modulen 'fileinfo' mangler. Vi anbefaler at du aktiverer denne modulen for å kunne detektere mime-typen korrekt.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Transaksjonsbasert fil-låsing er deaktivert. Dette kan føre til problemer med kappløpssituasjoner. Aktiver 'filelocking.enabled' i config.php for å unngå disse problemene. Se <a target=\"_blank\" href=\"%s\">dokumentasjonen ↗</a> for mer informasjon.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transaksjonsbasert fil-låsing er deaktivert. Dette kan føre til konflikt. Aktiver \"filelocking.enabled\" i config.php for å unngå disse problemene. Se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentasjonen ↗</a> for mer informasjon.",
     "System locale can not be set to a one which supports UTF-8." : "Kan ikke sette systemets nasjonale innstillinger til en som støtter UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Dette betyr at det kan forekomme problemer med visse tegn i filnavn.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Vi anbefaler sterkt å installere de påkrevde pakkene på systemet ditt for å støtte en av følgende nasjonale innstillinger: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Hvis installasjonen din ikke er installert i roten av domenet og bruker systemets cron, kan det bli problemer med URL-genereringen. For å unngå disse problemene, sett \"overwrite.cli.url\" i filen config.php til web-roten for installasjonen din (Foreslått: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Det var ikke mulig å kjøre cron-jobben vi CLI. Følgende tekniske feil oppstod:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Vennligst dobbeltsjekk <a target=\"_blank\" href=\"%s\">Installasjonsveiledningene ↗</a> og se etter feil og advarsler i <a href=\"#log-section\">loggen</a>.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Vennligst dobbeltsjekk <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installasjonsguidene ↗</a>, og se etter feil eller advarsler i <a href=\"#log-section\">loggen</a>.",
     "All checks passed." : "Alle sjekker bestått.",
     "Open documentation" : "Åpne dokumentasjonen",
     "Allow apps to use the Share API" : "Tillat apper å bruke API for Deling",
     "Allow users to share via link" : "Tillat brukere å dele via lenke",
-    "Enforce password protection" : "Krev passordbeskyttelse",
     "Allow public uploads" : "Tillat offentlig opplasting",
-    "Allow users to send mail notification for shared files" : "Tlllat at brukere sender e-postvarsler for delte filer",
+    "Enforce password protection" : "Krev passordbeskyttelse",
     "Set default expiration date" : "Sett standard utløpsdato",
+    "Allow users to send mail notification for shared files" : "Tlllat at brukere sender e-postvarsler for delte filer",
     "Expire after " : "Utløper etter",
     "days" : "dager",
     "Enforce expiration date" : "Krev utløpsdato",
     "Allow resharing" : "TIllat videre deling",
+    "Allow sharing with groups" : "Tillat deling med grupper",
     "Restrict users to only share with users in their groups" : "Begrens brukere til kun å dele med brukere i deres grupper",
     "Allow users to send mail notification for shared files to other users" : "Tillat at brukere sender varsler om delte filer på e-post til andre brukere",
     "Exclude groups from sharing" : "Utelukk grupper fra deling",
@@ -194,7 +207,7 @@ OC.L10N.register(
     "What to log" : "Hva som skal logges",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite brukes som database. For større installasjoner anbefaler vi å bytte til en annen database-server.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite er spesielt frarådet om man bruker desktopklienten til filsynkronisering",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "For å migrere til en annen database, bruk kommandolinjeverktøyet: 'occ db:convert-type', eller les i <a target=\"_blank\" href=\"%s\">dokumentasjonen ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "For å migrere til en annen database, bruk kommandolinjeverktøyet: 'occ db:convert-type', eller les i <a target=\"_blank\" href=\"%s\">dokumentasjonen ↗</a>.",
     "How to do backups" : "Hvordan ta sikkerhetskopier",
     "Advanced monitoring" : "Avansert overvåking",
     "Performance tuning" : "Forbedre ytelsen",
@@ -210,6 +223,8 @@ OC.L10N.register(
     "Documentation:" : "Dokumentasjon:",
     "User documentation" : "Brukerdokumentasjon",
     "Admin documentation" : "Admin-dokumentasjon",
+    "Visit website" : "Gå til nettside",
+    "Report a bug" : "Rapporter en feil",
     "Show description …" : "Vis beskrivelse …",
     "Hide description …" : "Skjul beskrivelse …",
     "This app has an update available." : "En oppdatering er tilgjengelig for denne appen.",
@@ -256,6 +271,17 @@ OC.L10N.register(
     "Change password" : "Endre passord",
     "Language" : "Språk",
     "Help translate" : "Bidra til oversettelsen",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Disse web-, skrivebords- og mobilklienter er pålogget din ownCloud for øyeblikket.",
+    "Browser" : "Nettleser",
+    "Most recent activity" : "Siste aktivitet",
+    "You've linked these apps." : "Du har lenket disse appene.",
+    "Name" : "Navn",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Et app-passord er et passord som gir en app eller en enhet tillatelse til å aksessere din %s-konto.",
+    "App name" : "App-navn",
+    "Create new app password" : "Lag nytt app-passord",
+    "Use the credentials below to configure your app or device." : "Bruk detaljene nedenfor for å konfigurere appen eller enheten din.",
+    "Username" : "Brukernavn",
+    "Done" : "Ferdig",
     "Get the apps to sync your files" : "Hent apper som synkroniserer filene dine",
     "Desktop client" : "Skrivebordsklient",
     "Android app" : "Android-app",
@@ -268,7 +294,6 @@ OC.L10N.register(
     "Show user backend" : "Vis bruker-server",
     "Send email to new user" : "Send e-post til ny bruker",
     "Show email address" : "Vis e-postadresse",
-    "Username" : "Brukernavn",
     "E-Mail" : "E-post",
     "Create" : "Opprett",
     "Admin Recovery Password" : "Administrativt gjenopprettingspassord",
@@ -279,7 +304,6 @@ OC.L10N.register(
     "Admins" : "Administratorer",
     "Default Quota" : "Standard kvote",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Legg inn lagringskvote (f.eks. \"512 MB\" eller \"12 GB\")",
-    "Unlimited" : "Ubegrenset",
     "Other" : "Annet",
     "Full Name" : "Fullt navn",
     "Group Admin for" : "Gruppeadministrator for",
