@@ -1,46 +1,28 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Avisos de configuração e segurança",
-    "Sharing" : "Partilha",
-    "Server-side encryption" : "Atualizar App",
-    "External Storage" : "Armazenamento Externo",
-    "Cron" : "Cron",
-    "Email server" : "Servidor de Correio Eletrónico",
-    "Log" : "Registo",
-    "Tips & tricks" : "Dicas e truqes",
-    "Updates" : "Atualizações",
-    "Couldn't remove app." : "Não foi possível remover a aplicação.",
-    "Language changed" : "Idioma alterado",
-    "Invalid request" : "Pedido Inválido",
-    "Authentication error" : "Erro na autenticação",
-    "Admins can't remove themself from the admin group" : "Os administradores não se podem remover a eles próprios do grupo 'admin'.",
-    "Unable to add user to group %s" : "Não é possível adicionar o utilizador ao grupo %s",
-    "Unable to remove user from group %s" : "Não é possível remover o utilizador do grupo %s",
-    "Couldn't update app." : "Não foi possível atualizar a app.",
     "Wrong password" : "Palavra-passe errada",
     "No user supplied" : "Nenhum utilizador especificado",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Por favor, forneça uma palavra-passe de recuperação de administrador, caso contrário seráo perdidos todos os dados",
+    "Authentication error" : "Erro na autenticação",
+    "Please provide an admin recovery password, otherwise all user data will be lost" : "Por favor, forneça uma palavra-passe de recuperação de administrador, caso contrário serão perdidos todos os dados",
     "Wrong admin recovery password. Please check the password and try again." : "Palavra-passe de recuperação de administrador errada. Por favor, verifique a palavra-passe e tente novamente.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "A interface não suporta a alteração da palavra-passe, mas a chave de encriptação foi atualizada com sucesso.",
     "Unable to change password" : "Não foi possível alterar a sua palavra-passe ",
     "Enabled" : "Ativada",
     "Not enabled" : "Desativada",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando e atualizando aplicações via loja de aplicações ou Partilha de Nuvem Federada",
-    "Federated Cloud Sharing" : "Partilha de Cloud Federada",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "A instalar e a atualizar as aplicações através da loja de aplicações ou Federated Cloud Sharing",
+    "Federated Cloud Sharing" : "Federated Cloud Sharing",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL está a usar uma versão %s desatualizada (%s). Por favor, atualize o seu sistema operativo ou algumas funcionalidades como %s não funcionarão corretamente.",
     "A problem occurred, please check your log files (Error: %s)" : "Ocorreu um problema, por favor, verifique os ficheiros de registo (Erro: %s)",
     "Migration Completed" : "Migração Concluída",
     "Group already exists." : "O grupo já existe.",
-    "Unable to add group." : "Impossível acrescentar o grupo.",
-    "Unable to delete group." : "Impossível apagar grupo.",
+    "Unable to add group." : "Impossível adicionar o grupo.",
+    "Unable to delete group." : "Impossível eliminar grupo.",
     "log-level out of allowed range" : "log-level fora do alcance permitido",
     "Saved" : "Guardado",
     "test email settings" : "testar as definições de e-mail",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Um problema ocorreu ao enviar o email. Por favor verifique as suas definições. (Erro: %s)",
-    "Email sent" : "Mensagem enviada",
+    "Email sent" : "Mensagem de correio eletrónico enviada",
     "You need to set your user email before being able to send test emails." : "Você precisa de configurar o seu e-mail de usuário antes de ser capaz de enviar e-mails de teste",
     "Invalid mail address" : "Endereço de correio eletrónico inválido",
     "A user with that name already exists." : "Já existe um utilizador com esse nome.",
@@ -53,6 +35,24 @@ OC.L10N.register(
     "Email saved" : "E-mail guardado",
     "Your full name has been changed." : "O seu nome completo foi alterado.",
     "Unable to change full name" : "Não foi possível alterar o seu nome completo",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Security & setup warnings" : "Avisos de configuração e segurança",
+    "Sharing" : "Partilha",
+    "Server-side encryption" : "Atualizar App",
+    "External Storage" : "Armazenamento Externo",
+    "Cron" : "Cron",
+    "Email server" : "Servidor de Correio Eletrónico",
+    "Log" : "Registo",
+    "Tips & tricks" : "Dicas e truques",
+    "Updates" : "Atualizações",
+    "Couldn't remove app." : "Não foi possível remover a aplicação.",
+    "Language changed" : "Idioma alterado",
+    "Invalid request" : "Pedido Inválido",
+    "Admins can't remove themself from the admin group" : "Os administradores não se podem remover a eles próprios do grupo 'admin'.",
+    "Unable to add user to group %s" : "Não é possível adicionar o utilizador ao grupo %s",
+    "Unable to remove user from group %s" : "Não é possível remover o utilizador do grupo %s",
+    "Couldn't update app." : "Não foi possível atualizar a app.",
     "Are you really sure you want add \"{domain}\" as trusted domain?" : "Você tem certeza que quer adicionar \"{domain}\" como domínio confiável?",
     "Add trusted domain" : "Adicionar domínio confiável ",
     "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor, aguarde até que a mesma esteja concluída..",
@@ -63,6 +63,7 @@ OC.L10N.register(
     "Experimental" : "Experimental",
     "All" : "Todos",
     "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
+    "The app will be downloaded from the app store" : "A aplicação será descarregada da loja de aplicações",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "As apps oficiais são desenvolvidas por e na comunidade da ownCloud. Elas oferecem funcionalidade central para a ownCloud e está pronta para uma utilização na produção.",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "As aplicações aprovadas são desenvolvidas por developers de confiança e passaram numa verificação de segurança. São mantidas ativamente num repositório de código aberto e quem as mantém considera-as estáveis para uso casual a normal.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicação não foi verificada por problemas de segurança e é nova ou conhecida por ser instável. Instale-a por sua conta e risco.",
@@ -73,6 +74,9 @@ OC.L10N.register(
     "Disable" : "Desativar",
     "Enable" : "Ativar",
     "Error while enabling app" : "Ocorreu um erro enquanto ativava a app",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Erro: esta app não pode ser activada porque torna o servidor instável",
+    "Error: could not disable broken app" : "Erro: não foi possível desactivar app estragada",
+    "Error while disabling broken app" : "Erro ao desactivar app estragada",
     "Updating...." : "A atualizar...",
     "Error while updating app" : "Ocorreu um erro enquanto atualizava a app",
     "Updated" : "Atualizada",
@@ -81,7 +85,11 @@ OC.L10N.register(
     "Uninstall" : "Desinstalar",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicação foi ativada, mas precisa de ser atualizada. Você será redirecionado para a página de atualização em 5 segundos.",
     "App update" : "Atualizar App",
-    "No apps found for \"{query}\"" : "Não foram encontradas aplicações para \"{query}\"",
+    "No apps found for {query}" : "Não foram encontradas aplicações para {query}",
+    "Disconnect" : "Desligado",
+    "Error while loading browser sessions and device tokens" : "Erro durante o carregamento das sessões do navegador e tokens do dispositivo",
+    "Error while creating device token" : "Erro durante a criação do token do dispositivo",
+    "Error while deleting the token" : "Erro durante a eliminação do token",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor, envie um certificado PEM codificado em ASCII.",
     "Valid until {date}" : "Válida até {date}",
     "Delete" : "Apagar",
@@ -108,7 +116,9 @@ OC.L10N.register(
     "A valid password must be provided" : "Deve ser indicada uma palavra-passe válida",
     "A valid email must be provided" : "Deve ser fornecido um email válido",
     "__language_name__" : "__language_name__",
+    "Unlimited" : "Ilimitado",
     "Personal info" : "Informação pessoal",
+    "Sessions" : "Sessões",
     "Sync clients" : "Clientes de sync",
     "Everything (fatal issues, errors, warnings, info, debug)" : "Tudo (problemas fatais, erros, avisos, informação, depuração)",
     "Info, warnings, errors and fatal issues" : "Informação, avisos, erros e problemas fatais",
@@ -122,32 +132,34 @@ OC.L10N.register(
     "SSL" : "SSL",
     "TLS" : "TLS",
     "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php não parece estar bem instalado para consultar variáveis de ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor, verifique a <a target=\"_blank\" href=\"%s\">documentação de instalação ↗</a> para notas de configuração do php e configuração php do seu servidor, especialmente quando utiliza php-fpm.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor, verifique a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação de instalação ↗</a> para notas de configuração do php e configuração php do seu servidor, especialmente quando utiliza php-fpm.",
     "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado a remover blocos doc em linha. Isto vai fazer algumas aplicações basicas inacessíveis.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "O PHP está aparentemente configurado para remover blocos doc em linha. Isto vai tornar inacessíveis várias aplicações básicas.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
     "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "O seu servidor está a correr Microsoft Windows. Nós recomendamos Linux para uma experiência de utilizador optimizada.",
     "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s abaixo da versão %2$s está instalado. Por motivos de estabilidade e desempenho, recomendamos que atualize para a nova versão %1$s.",
     "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "O Módulo PHP 'fileinfo' não se encontra instalado/activado. É fortemente recomendado que active este módulo para obter os melhores resultado com a detecção dos tipos de mime.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivos transacionais está desativado, isto poderá levar a problemas com condições de corrida. Ative 'filelocking.enabled' no config.php para evitar estes problemas. Consulte a <a target=\"_blank\" href=\"%s\">documentação ↗</a> para mais informação.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivos transacionais está desativado, isto poderá levar a problemas com condições de corrida. Ative 'filelocking.enabled' no config.php para evitar estes problemas. Consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a> para mais informação.",
     "System locale can not be set to a one which supports UTF-8." : "Não é possível definir a internacionalização do sistema para um que suporte o UTF-8.",
     "This means that there might be problems with certain characters in file names." : "Isto significa que podem haver problemas com alguns caracteres nos nomes dos ficheiros.",
     "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nós recomendamos fortemente que instale no seu sistema os pacotes necessários para suportar uma das seguintes locallidades: %s.",
     "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se a sua instalação não está instalada na raiz do domínio e usa o sistema cron, pode haver problemas com a geração de URL. Para evitar esses problemas, por favor, defina a opção \"overwrite.cli.url\" no ficheiro config.php para o caminho webroot da sua instalação (Sugestão: \"%s\")",
     "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Não foi possível executar o cronjob via CLI. Os seguintes erros técnicos apareceram:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, verifique os <a target=\"_blank\" href=\"%s\">guias de instalação ↗</a>, e verifique se existe algum erro ou aviso no <a href=\"#log-section\">log</a>.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, verifique os <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guias de instalação ↗</a>, e verifique se existe algum erro ou aviso no <a href=\"#log-section\">log</a>.",
     "All checks passed." : "Todas as verificações passaram.",
     "Open documentation" : "Abrir documentação",
     "Allow apps to use the Share API" : "Permitir que os utilizadores usem a API de partilha",
     "Allow users to share via link" : "Permitir que os utilizadores partilhem através do link",
-    "Enforce password protection" : "Forçar proteção por palavra-passe",
     "Allow public uploads" : "Permitir Envios Públicos",
-    "Allow users to send mail notification for shared files" : "Permita que o utilizador envie notificações por correio electrónico para ficheiros partilhados",
+    "Enforce password protection" : "Forçar proteção por palavra-passe",
     "Set default expiration date" : "Especificar a data padrão de expiração",
+    "Allow users to send mail notification for shared files" : "Permita que o utilizador envie notificações por correio electrónico para ficheiros partilhados",
     "Expire after " : "Expira após",
     "days" : "dias",
     "Enforce expiration date" : "Forçar a data de expiração",
     "Allow resharing" : "Permitir repartilha",
+    "Allow sharing with groups" : "Permitir partilha com grupos.",
     "Restrict users to only share with users in their groups" : "Restringe os utilizadores só a partilhar com utilizadores do seu grupo",
     "Allow users to send mail notification for shared files to other users" : "Autorizar utilizadores a enviarem notificações de email acerca de ficheiros partilhados a outros utilizadores",
     "Exclude groups from sharing" : "Excluir grupos das partilhas",
@@ -194,7 +206,7 @@ OC.L10N.register(
     "What to log" : "Fazer log do quê?",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite é utilizado como uma base de dados. Para instalações maiores nós recomendamos que mude para uma interface de base de dados diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "O uso de SQLite é desencorajado especialmente se estiver a pensar em dar uso ao cliente desktop para sincronizar os seus ficheiros no seu computador.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Para migrar para outro tipo de base de dados, use a ferramenta de comando de linha: 'occ db:convert-type', ou seja a <a target=\"_blank\" href=\"%s\">documentação↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Para migrar para outro tipo de base de dados, use a ferramenta de comando de linha: 'occ db:convert-type', ou veja a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação↗</a>.",
     "How to do backups" : "Como fazer cópias de segurança",
     "Advanced monitoring" : "Monitorização avançada",
     "Performance tuning" : "Ajuste de desempenho",
@@ -210,6 +222,7 @@ OC.L10N.register(
     "Documentation:" : "Documentação:",
     "User documentation" : "Documentação de Utilizador",
     "Admin documentation" : "Documentação do Administrador",
+    "Report a bug" : "Reportar um erro",
     "Show description …" : "Mostrar descrição ...",
     "Hide description …" : "Esconder descrição ...",
     "This app has an update available." : "Esta aplicação tem uma atualização disponível.",
@@ -256,6 +269,12 @@ OC.L10N.register(
     "Change password" : "Alterar palavra-passe",
     "Language" : "Idioma",
     "Help translate" : "Ajude a traduzir",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Estes são os clientes web, desktop e móveis actualmente ligados à sua ownCloud.",
+    "Browser" : "Navegador",
+    "Most recent activity" : "Atividade mais recente",
+    "Name" : "Nome",
+    "Username" : "Nome de utilizador",
+    "Done" : "Concluído",
     "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
     "Desktop client" : "Cliente Desktop",
     "Android app" : "Aplicação Android",
@@ -268,7 +287,6 @@ OC.L10N.register(
     "Show user backend" : "Mostrar interface do utilizador",
     "Send email to new user" : "Enviar email ao novo utilizador",
     "Show email address" : "Mostrar endereço de email",
-    "Username" : "Nome de utilizador",
     "E-Mail" : "Correio Eletrónico",
     "Create" : "Criar",
     "Admin Recovery Password" : "Recuperação da Palavra-passe de Administrador",
@@ -279,7 +297,6 @@ OC.L10N.register(
     "Admins" : "Administrador",
     "Default Quota" : "Quota por padrão",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Insira a quota de armazenamento (ex: \"512 MB\" ou \"12 GB\")",
-    "Unlimited" : "Ilimitado",
     "Other" : "Outro",
     "Full Name" : "Nome completo",
     "Group Admin for" : "Administrador de Grupo para",
